@@ -17,16 +17,19 @@ limitations under the License.
 package v1alpha1
 
 import (
+	"bytes"
 	"context"
 	"encoding/json"
 	"fmt"
 	"strconv"
 	"strings"
+	"sync"
 	"time"
 
 	liberr "github.com/konveyor/controller/pkg/error"
 	pvdr "github.com/konveyor/mig-controller/pkg/cloudprovider"
 	"github.com/konveyor/mig-controller/pkg/compat"
+	"github.com/konveyor/mig-controller/pkg/remote"
 	"github.com/pkg/errors"
 	"k8s.io/client-go/kubernetes/scheme"
 	"sigs.k8s.io/controller-runtime/pkg/client/config"
@@ -53,12 +56,19 @@ const (
 
 // migration-cluster-config configmap
 const (
-	ClusterConfigMapName  = "migration-cluster-config"
-	RegistryImageKey      = "REGISTRY_IMAGE"
-	StagePodImageKey      = "STAGE_IMAGE"
-	RsyncTransferImageKey = "RSYNC_TRANSFER_IMAGE"
-	ClusterSubdomainKey   = "CLUSTER_SUBDOMAIN"
-	OperatorVersionKey    = "OPERATOR_VERSION"
+	ClusterConfigMapName          = "migration-cluster-config"
+	RegistryImageKey              = "REGISTRY_IMAGE"
+	StagePodImageKey              = "STAGE_IMAGE"
+	RsyncTransferImageKey         = "RSYNC_TRANSFER_IMAGE"
+	ClusterSubdomainKey           = "CLUSTER_SUBDOMAIN"
+	OperatorVersionKey            = "OPERATOR_VERSION"
+	RegistryReadinessProbeTimeout = "REGISTRY_READINESS_TIMEOUT"
+	RegistryLivenessProbeTimeout  = "REGISTRY_LIVENESS_TIMEOUT"
+)
+
+// constants
+const (
+	RegistryDefaultProbeTimeout = 3
 )
 
 // MigClusterSpec defines the desired state of MigCluster
@@ -146,18 +156,126 @@ func (m *MigCluster) GetServiceAccountSecret(client k8sclient.Client) (*kapi.Sec
 	return GetSecret(client, m.Spec.ServiceAccountSecretRef)
 }
 
-// GetClient get a local or remote client using a MigCluster and an existing client
-func (m *MigCluster) GetClient(c k8sclient.Client) (compat.Client, error) {
-	restConfig, err := m.BuildRestConfig(c)
-	if err != nil {
-		return nil, err
+var cachedClientMap compatClientMap
+var uncachedClientMap compatClientMap
+
+// Maps MigCluster UID to stored compat.Client for that cluster.
+type compatClientMap struct {
+	cMap  map[types.UID]compat.Client
+	mutex sync.RWMutex
+}
+
+func (cm *compatClientMap) init() {
+	if cm.cMap == nil {
+		cm.cMap = make(map[types.UID]compat.Client)
 	}
-	client, err := compat.NewClient(restConfig)
+}
+
+func (cm *compatClientMap) Get(key types.UID) (compat.Client, bool) {
+	cm.mutex.RLock()
+	defer cm.mutex.RUnlock()
+	val, found := cm.cMap[key]
+	return val, found
+}
+
+func (cm *compatClientMap) Set(key types.UID, val compat.Client) {
+	cm.mutex.Lock()
+	defer cm.mutex.Unlock()
+	cm.cMap[key] = val
+}
+
+func (cm *compatClientMap) Delete(key types.UID) {
+	cm.mutex.Lock()
+	defer cm.mutex.Unlock()
+	delete(cm.cMap, key)
+}
+
+func init() {
+	cachedClientMap.init()
+	uncachedClientMap.init()
+}
+
+// GetClient gets a host or remote compat.Client for interacting with a MigCluster.
+// For best performance, returns the first available from this list:
+// 1) compat.Client with cache from map
+// 2) compat.Client with cache by building from manager k8s client
+// 3) compat.Client without cache from map
+// 4) compat.Client without cache by building from restConfig
+func (m *MigCluster) GetClient(c k8sclient.Client) (compat.Client, error) {
+	var cachedClusterClient *k8sclient.Client
+
+	// RestConfig is used to build client from scratch, and to invalidate stored clients
+	// when credentials and coordinates of MigClusters change.
+	clusterRestConfig, err := m.BuildRestConfig(c)
 	if err != nil {
 		return nil, err
 	}
 
-	return client, nil
+	if Settings.EnableCachedClient {
+		// Get manager cached k8s client if one exists
+		if m.Spec.IsHostCluster {
+			// Host cluster always has a cached k8s client
+			cachedClusterClient = &c
+		} else {
+			// Remote cluster has a cached k8s client if remote manager has been started
+			rwm := remote.GetWatchMap()
+			remoteCluster := rwm.Get(types.NamespacedName{Namespace: m.Namespace, Name: m.Name})
+			if remoteCluster != nil {
+				cachedClientConfig := remoteCluster.RemoteManager.GetConfig()
+				cachedClient := remoteCluster.RemoteManager.GetClient()
+				if AreRestConfigsEqual(cachedClientConfig, clusterRestConfig) {
+					cachedClusterClient = &cachedClient
+				}
+			}
+		}
+		// 1) compat.Client with cache from map
+		if compatClient, ok := cachedClientMap.Get(m.UID); ok {
+			if AreRestConfigsEqual(compatClient.RestConfig(), clusterRestConfig) {
+				return compatClient, nil
+			} else {
+				// Handle change of restConfig for MigCluster
+				cachedClientMap.Delete(m.UID)
+			}
+		}
+
+		// 2) compat.Client with cache by building from manager k8s client
+		if cachedClusterClient != nil {
+			compatClient, err := compat.NewClient(clusterRestConfig, cachedClusterClient)
+			if err != nil {
+				return nil, err
+			}
+			cachedClientMap.Set(m.UID, compatClient)
+			return compatClient, nil
+		}
+	}
+
+	// 3) compat.Client without cache from map
+	if compatClient, ok := uncachedClientMap.Get(m.UID); ok {
+		if AreRestConfigsEqual(compatClient.RestConfig(), clusterRestConfig) {
+			return compatClient, nil
+		} else {
+			// Handle change of restConfig for MigCluster
+			uncachedClientMap.Delete(m.UID)
+		}
+	}
+
+	// 4) compat.Client without cache by building from restConfig
+	uncachedClusterClient, err := k8sclient.New(
+		clusterRestConfig,
+		k8sclient.Options{
+			Scheme: scheme.Scheme,
+		})
+	if err != nil {
+		return nil, err
+	}
+
+	compatClient, err := compat.NewClient(clusterRestConfig, &uncachedClusterClient)
+	if err != nil {
+		return nil, err
+	}
+
+	uncachedClientMap.Set(m.UID, compatClient)
+	return compatClient, nil
 }
 
 func (m *MigCluster) GetClusterConfigMap(c k8sclient.Client) (*corev1.ConfigMap, error) {
@@ -186,6 +304,52 @@ func (m *MigCluster) GetRegistryImage(c k8sclient.Client) (string, error) {
 	return registryImage, nil
 }
 
+// GetRegistryLivenessTimeout returns liveness timeout value for migration registry
+func (m *MigCluster) GetRegistryLivenessTimeout(c k8sclient.Client) (int32, error) {
+	clusterConfig, err := m.GetClusterConfigMap(c)
+	if err != nil {
+		return -1, liberr.Wrap(err)
+	}
+	registryLivenessTimeout, found := clusterConfig.Data[RegistryLivenessProbeTimeout]
+	// When registry timeout value is not found in the configmap, the user didn't intend to use a custom timeout
+	// therefore, we return the default value in this case
+	if !found {
+		return RegistryDefaultProbeTimeout, nil
+	}
+	// When registry timeout is defined, but it is not a valid +ve integer, it indicates the intention of the user to set
+	// the value but has a mistake, therefore, we do not use the default value and return an error instead
+	if val, err := strconv.ParseInt(registryLivenessTimeout, 10, 32); err != nil {
+		return -1, liberr.Wrap(err)
+	} else if val < 1 {
+		return -1, fmt.Errorf("non-positive value set for Migration Registry liveness timeout")
+	} else {
+		return int32(val), nil
+	}
+}
+
+// GetRegistryReadinessTimeout returns readiness timeout value for migration registry
+func (m *MigCluster) GetRegistryReadinessTimeout(c k8sclient.Client) (int32, error) {
+	clusterConfig, err := m.GetClusterConfigMap(c)
+	if err != nil {
+		return -1, liberr.Wrap(err)
+	}
+	registryReadinessTimeout, found := clusterConfig.Data[RegistryReadinessProbeTimeout]
+	// When registry timeout value is not found in the configmap, the user didn't intend to use a custom timeout
+	// therefore, we return the default value in this case
+	if !found {
+		return RegistryDefaultProbeTimeout, nil
+	}
+	// When registry timeout is defined, but it is not a valid +ve integer, it indicates the intention of the user to set
+	// the value but has a mistake, therefore, we do not use the default value and return an error instead
+	if val, err := strconv.ParseInt(registryReadinessTimeout, 10, 32); err != nil {
+		return -1, liberr.Wrap(err)
+	} else if val < 1 {
+		return -1, fmt.Errorf("non-positive value set for Migration Registry readiness timeout")
+	} else {
+		return int32(val), nil
+	}
+}
+
 // GetRsyncTransferImage gets a MigCluster specific rsync transfer image from ConfigMap
 func (m *MigCluster) GetRsyncTransferImage(c k8sclient.Client) (string, error) {
 	client, err := m.GetClient(c)
@@ -310,7 +474,7 @@ func (m *MigCluster) DeleteResources(client k8sclient.Client, labels map[string]
 
 	// Deployment
 	dList := appv1.DeploymentList{}
-	err = client.List(context.TODO(), options, &dList)
+	err = client.List(context.TODO(), &dList, options)
 	if err != nil {
 		return err
 	}
@@ -323,7 +487,7 @@ func (m *MigCluster) DeleteResources(client k8sclient.Client, labels map[string]
 
 	// DeploymentConfig
 	dcList := ocapi.DeploymentConfigList{}
-	err = client.List(context.TODO(), options, &dcList)
+	err = client.List(context.TODO(), &dcList, options)
 	if err != nil {
 		return err
 	}
@@ -336,7 +500,7 @@ func (m *MigCluster) DeleteResources(client k8sclient.Client, labels map[string]
 
 	// Service
 	svList := kapi.ServiceList{}
-	err = client.List(context.TODO(), options, &svList)
+	err = client.List(context.TODO(), &svList, options)
 	if err != nil {
 		return err
 	}
@@ -349,7 +513,7 @@ func (m *MigCluster) DeleteResources(client k8sclient.Client, labels map[string]
 
 	// Pod
 	pList := kapi.PodList{}
-	err = client.List(context.TODO(), options, &pList)
+	err = client.List(context.TODO(), &pList, options)
 	if err != nil {
 		return err
 	}
@@ -362,7 +526,7 @@ func (m *MigCluster) DeleteResources(client k8sclient.Client, labels map[string]
 
 	// Secret
 	sList := kapi.SecretList{}
-	err = client.List(context.TODO(), options, &sList)
+	err = client.List(context.TODO(), &sList, options)
 	if err != nil {
 		return err
 	}
@@ -375,7 +539,7 @@ func (m *MigCluster) DeleteResources(client k8sclient.Client, labels map[string]
 
 	// ImageStream
 	iList := imgapi.ImageStreamList{}
-	err = client.List(context.TODO(), options, &iList)
+	err = client.List(context.TODO(), &iList, options)
 	if err != nil {
 		return err
 	}
@@ -388,7 +552,7 @@ func (m *MigCluster) DeleteResources(client k8sclient.Client, labels map[string]
 
 	// Backup
 	bList := velero.BackupList{}
-	err = client.List(context.TODO(), options, &bList)
+	err = client.List(context.TODO(), &bList, options)
 	if err != nil {
 		return err
 	}
@@ -401,7 +565,7 @@ func (m *MigCluster) DeleteResources(client k8sclient.Client, labels map[string]
 
 	// Restore
 	rList := velero.RestoreList{}
-	err = client.List(context.TODO(), options, &rList)
+	err = client.List(context.TODO(), &rList, options)
 	if err != nil {
 		return err
 	}
@@ -414,7 +578,7 @@ func (m *MigCluster) DeleteResources(client k8sclient.Client, labels map[string]
 
 	// BSL
 	bslList := velero.BackupStorageLocationList{}
-	err = client.List(context.TODO(), options, &bslList)
+	err = client.List(context.TODO(), &bslList, options)
 	if err != nil {
 		return err
 	}
@@ -427,7 +591,7 @@ func (m *MigCluster) DeleteResources(client k8sclient.Client, labels map[string]
 
 	// VSL
 	vslList := velero.VolumeSnapshotLocationList{}
-	err = client.List(context.TODO(), options, &vslList)
+	err = client.List(context.TODO(), &vslList, options)
 	if err != nil {
 		return err
 	}
@@ -580,8 +744,8 @@ func (r *MigCluster) GetKubeStorageClasses(client k8sclient.Client) ([]storageap
 	list := storageapi.StorageClassList{}
 	err := client.List(
 		context.TODO(),
-		&k8sclient.ListOptions{},
-		&list)
+		&list,
+		&k8sclient.ListOptions{})
 	if err != nil {
 		return nil, err
 	}
@@ -606,8 +770,8 @@ func (m *MigCluster) GetInternalRegistryPath(c k8sclient.Client) (string, error)
 	isList := imgapi.ImageStreamList{}
 	err = client.List(
 		context.TODO(),
-		k8sclient.InNamespace("openshift"),
-		&isList)
+		&isList,
+		k8sclient.InNamespace("openshift"))
 	if err == nil && len(isList.Items) > 0 {
 		if value := isList.Items[0].Status.DockerImageRepository; len(value) > 0 {
 			ref, err := reference.Parse(value)
@@ -749,3 +913,23 @@ func (r *MigCluster) GetObjectReference() *kapi.ObjectReference {
 		Namespace: r.Namespace,
 	}
 }
+
+// AreRestConfigsEqual given a new rest config, checks whether cluster's config is equal to it
+func AreRestConfigsEqual(c1, c2 *rest.Config) bool {
+	if c1 == nil || c2 == nil {
+		return false
+	}
+	if c1.Host != c2.Host {
+		return false
+	}
+	if c1.BearerToken != c2.BearerToken {
+		return false
+	}
+	if c1.TLSClientConfig.Insecure != c2.TLSClientConfig.Insecure {
+		return false
+	}
+	if !bytes.Equal(c1.TLSClientConfig.CAData, c2.TLSClientConfig.CAData) {
+		return false
+	}
+	return true
+}
