@@ -215,10 +215,9 @@ func (r *MigPlan) ListMigrations(client k8sclient.Client) ([]*MigMigration, erro
 	// Search
 	err := client.List(
 		context.TODO(),
-		k8sclient.MatchingField(
-			PlanIndexField,
-			fmt.Sprintf("%s/%s", r.Namespace, r.Name)),
-		&qlist)
+		&qlist,
+		k8sclient.MatchingFields{PlanIndexField: fmt.Sprintf("%s/%s", r.Namespace, r.Name)},
+	)
 	if err != nil {
 		return nil, err
 	}
@@ -298,8 +297,8 @@ func (r *MigPlan) GetRegistrySecret(client k8sclient.Client) (*kapi.Secret, erro
 	labels[MigrationRegistryLabel] = True
 	err := client.List(
 		context.TODO(),
-		k8sclient.MatchingLabels(labels),
-		&list)
+		&list,
+		k8sclient.MatchingLabels(labels))
 	if err != nil {
 		return nil, err
 	}
@@ -317,19 +316,27 @@ func (r *MigPlan) EqualsRegistrySecret(a, b *kapi.Secret) bool {
 }
 
 // Build a Registry Deployment.
-func (r *MigPlan) BuildRegistryDeployment(storage *MigStorage, proxySecret *kapi.Secret, name, dirName, registryImage string) *appsv1.Deployment {
-	labels := r.GetCorrelationLabels()
-	labels[MigrationRegistryLabel] = True
-	labels["app"] = name
-	labels["migplan"] = string(r.UID)
+func (r *MigPlan) BuildRegistryDeployment(storage *MigStorage, proxySecret *kapi.Secret, name,
+	dirName, registryImage string, mCorrelationLabels map[string]string, livenessTimeout int32, readinessTimeout int32) *appsv1.Deployment {
+	// Merge correlation labels for plan and migration
+	combinedLabels := r.GetCorrelationLabels()
+	if mCorrelationLabels != nil {
+		for k, v := range mCorrelationLabels {
+			combinedLabels[k] = v
+		}
+	}
+	combinedLabels[MigrationRegistryLabel] = True
+	combinedLabels["app"] = name
+	combinedLabels["migplan"] = string(r.UID)
+
 	deployment := &appsv1.Deployment{
 		ObjectMeta: metav1.ObjectMeta{
-			Labels:    labels,
+			Labels:    combinedLabels,
 			Name:      name,
 			Namespace: VeleroNamespace,
 		},
 	}
-	r.UpdateRegistryDeployment(storage, deployment, proxySecret, name, dirName, registryImage)
+	r.UpdateRegistryDeployment(storage, deployment, proxySecret, name, dirName, registryImage, mCorrelationLabels, livenessTimeout, readinessTimeout)
 	return deployment
 }
 
@@ -342,11 +349,11 @@ func (r *MigPlan) GetProxySecret(client k8sclient.Client) (*kapi.Secret, error)
 	})
 	err := client.List(
 		context.TODO(),
+		&list,
 		&k8sclient.ListOptions{
 			Namespace:     VeleroNamespace,
 			LabelSelector: selector,
 		},
-		&list,
 	)
 	// If error listing secrets return no env vars
 	if err != nil {
@@ -365,7 +372,8 @@ func (r *MigPlan) GetProxySecret(client k8sclient.Client) (*kapi.Secret, error)
 }
 
 // Update a Registry Deployment as desired for the specified cluster.
-func (r *MigPlan) UpdateRegistryDeployment(storage *MigStorage, deployment *appsv1.Deployment, proxySecret *kapi.Secret, name, dirName, registryImage string) {
+func (r *MigPlan) UpdateRegistryDeployment(storage *MigStorage, deployment *appsv1.Deployment,
+	proxySecret *kapi.Secret, name, dirName, registryImage string, mCorrelationLabels map[string]string, livenessTimeout int32, readinessTimeout int32) {
 
 	envFrom := []kapi.EnvFromSource{}
 	// If Proxy secret exists, set env from it
@@ -380,23 +388,26 @@ func (r *MigPlan) UpdateRegistryDeployment(storage *MigStorage, deployment *apps
 		envFrom = append(envFrom, source)
 	}
 
+	// Merge migration correlation labels with Pod labels
+	podLabels := map[string]string{
+		"app":                  name,
+		"deployment":           name,
+		"migplan":              string(r.UID),
+		MigrationRegistryLabel: True,
+	}
+	if mCorrelationLabels != nil {
+		for k, v := range mCorrelationLabels {
+			podLabels[k] = v
+		}
+	}
+
 	deployment.Spec = appsv1.DeploymentSpec{
 		Replicas: pointer.Int32Ptr(1),
-		Selector: metav1.SetAsLabelSelector(map[string]string{
-			"app":                  name,
-			"deployment":           name,
-			"migplan":              string(r.UID),
-			MigrationRegistryLabel: True,
-		}),
+		Selector: metav1.SetAsLabelSelector(podLabels),
 		Template: kapi.PodTemplateSpec{
 			ObjectMeta: metav1.ObjectMeta{
 				CreationTimestamp: metav1.Time{},
-				Labels: map[string]string{
-					"app":                  name,
-					"deployment":           name,
-					"migplan":              string(r.UID),
-					MigrationRegistryLabel: True,
-				},
+				Labels:            podLabels,
 			},
 			Spec: kapi.PodSpec{
 				Containers: []kapi.Container{
@@ -419,7 +430,7 @@ func (r *MigPlan) UpdateRegistryDeployment(storage *MigStorage, deployment *apps
 								},
 							},
 							PeriodSeconds:       5,
-							TimeoutSeconds:      3,
+							TimeoutSeconds:      livenessTimeout,
 							InitialDelaySeconds: 15,
 						},
 						ReadinessProbe: &kapi.Probe{
@@ -430,7 +441,7 @@ func (r *MigPlan) UpdateRegistryDeployment(storage *MigStorage, deployment *apps
 								},
 							},
 							PeriodSeconds:       5,
-							TimeoutSeconds:      3,
+							TimeoutSeconds:      readinessTimeout,
 							InitialDelaySeconds: 15,
 						},
 						Resources: kapi.ResourceRequirements{},
@@ -463,8 +474,8 @@ func (r *MigPlan) GetRegistryDeployment(client k8sclient.Client) (*appsv1.Deploy
 	labels[MigrationRegistryLabel] = True
 	err := client.List(
 		context.TODO(),
-		k8sclient.MatchingLabels(labels),
-		&list)
+		&list,
+		k8sclient.MatchingLabels(labels))
 	if err != nil {
 		return nil, err
 	}
@@ -542,8 +553,8 @@ func (r *MigPlan) GetRegistryService(client k8sclient.Client) (*kapi.Service, er
 	labels[MigrationRegistryLabel] = True
 	err := client.List(
 		context.TODO(),
-		k8sclient.MatchingLabels(labels),
-		&list)
+		&list,
+		k8sclient.MatchingLabels(labels))
 	if err != nil {
 		return nil, err
 	}
@@ -572,8 +583,8 @@ func (r *MigPlan) GetBSL(client k8sclient.Client) (*velero.BackupStorageLocation
 	labels := r.GetCorrelationLabels()
 	err := client.List(
 		context.TODO(),
-		k8sclient.MatchingLabels(labels),
-		&list)
+		&list,
+		k8sclient.MatchingLabels(labels))
 	if err != nil {
 		return nil, err
 	}
@@ -591,8 +602,8 @@ func (r *MigPlan) GetVSL(client k8sclient.Client) (*velero.VolumeSnapshotLocatio
 	labels := r.GetCorrelationLabels()
 	err := client.List(
 		context.TODO(),
-		k8sclient.MatchingLabels(labels),
-		&list)
+		&list,
+		k8sclient.MatchingLabels(labels))
 	if err != nil {
 		return nil, err
 	}
@@ -639,6 +650,21 @@ func (r *MigPlan) GetDestinationNamespaces() []string {
 	return includedNamespaces
 }
 
+// GetNamespaceMapping gets a map of src to dest namespaces
+func (r *MigPlan) GetNamespaceMapping() map[string]string {
+	nsMapping := make(map[string]string)
+	for _, namespace := range r.Spec.Namespaces {
+		namespaces := strings.Split(namespace, ":")
+		if len(namespaces) > 1 {
+			nsMapping[namespaces[0]] = namespaces[1]
+		} else {
+			nsMapping[namespaces[0]] = namespaces[0]
+		}
+	}
+
+	return nsMapping
+}
+
 // Get whether the plan conflicts with another.
 // Plans conflict when:
 //   - Have any of the clusters in common.
