@@ -29,7 +29,7 @@ func getTestRsyncPodForPVC(podName string, pvcName string, ns string, attemptNo
 			Name:      podName,
 			Namespace: ns,
 			Labels: map[string]string{
-				migapi.RsyncPodIdentityLabel: pvcName,
+				migapi.RsyncPodIdentityLabel: getMD5Hash(pvcName),
 				RsyncAttemptLabel:            attemptNo,
 			},
 		},
@@ -74,7 +74,7 @@ func getRsyncClientPodRequirements(pvcName string, ns string) rsyncClientPodRequ
 		image:      "quay.io/konveyor/rsync-transfer:latest",
 		password:   "verySecurePassword",
 		privileged: false,
-		resourceReq: corev1.ResourceRequirements{
+		rsyncResourceReq: corev1.ResourceRequirements{
 			Limits: corev1.ResourceList{
 				corev1.ResourceCPU:    resource.MustParse("1"),
 				corev1.ResourceMemory: resource.MustParse("1Gi"),
@@ -1020,7 +1020,12 @@ func TestTask_ensureRsyncOperations(t *testing.T) {
 			}
 			podExistsInSource := func(pod *corev1.Pod) bool {
 				srcPods := corev1.PodList{}
-				errs := tt.args.client.List(context.TODO(), k8sclient.InNamespace(pod.Namespace).MatchingLabels(pod.Labels), &srcPods)
+				errs := tt.args.client.List(
+					context.TODO(),
+					&srcPods,
+					k8sclient.InNamespace(pod.Namespace),
+					k8sclient.MatchingLabels(pod.Labels),
+				)
 				if errs != nil {
 					t.Errorf("RsyncOperationsContext.EnsureRsyncOperations() failed getting pods in source namespace")
 				}
@@ -1150,43 +1155,3 @@ func TestTask_processRsyncOperationStatus(t *testing.T) {
 		})
 	}
 }
-
-func Test_getDNSSafeName(t *testing.T) {
-	tests := []struct {
-		name       string
-		volumeName string
-		want       string
-		wantErr    bool
-	}{
-		{
-			name:       "valid name",
-			volumeName: "valid",
-			want:       "valid",
-			wantErr:    false,
-		},
-		{
-			name:       "longer than 63 chars",
-			volumeName: strings.Repeat("1", 64),
-			want:       strings.Repeat("1", 63),
-			wantErr:    false,
-		},
-		{
-			name:       "valid length but invalid characters",
-			volumeName: "11111.11111%11111/11111",
-			want:       "11111-11111-11111-11111",
-			wantErr:    false,
-		},
-	}
-	for _, tt := range tests {
-		t.Run(tt.name, func(t *testing.T) {
-			got, err := getDNSSafeName(tt.volumeName)
-			if (err != nil) != tt.wantErr {
-				t.Errorf("getDNSSafeName() error = %v, wantErr %v", err, tt.wantErr)
-				return
-			}
-			if got != tt.want {
-				t.Errorf("getDNSSafeName() got = %v, want %v", got, tt.want)
-			}
-		})
-	}
-}
