@@ -21,6 +21,7 @@ import (
 	"fmt"
 	"io"
 	"math"
+	"path"
 	"regexp"
 	"strconv"
 	"strings"
@@ -49,8 +50,6 @@ import (
 
 var log = logging.WithName("pvmigrationprogress")
 
-var TimeLimit = 10 * time.Minute
-
 const (
 	// CreatingContainer initial container state
 	ContainerCreating = "ContainerCreating"
@@ -61,6 +60,10 @@ const (
 	RsyncContainerName          = "rsync-client"
 )
 
+type GetPodLogger interface {
+	getPodLogs(pod *kapi.Pod, containerName string, tailLines *int64, previous bool) (string, error)
+}
+
 // Add creates a new DirectVolumeMigrationProgress Controller and adds it to the Manager with default RBAC. The Manager will set fields on the Controller
 // and Start it when the Manager is Started.
 func Add(mgr manager.Manager) error {
@@ -104,10 +107,9 @@ type ReconcileDirectVolumeMigrationProgress struct {
 // Automatically generate RBAC rules to allow the Controller to read and write Deployments
 // +kubebuilder:rbac:groups=migration.openshift.io,resources=directvolumemigrationprogresses,verbs=get;list;watch;create;update;patch;delete
 // +kubebuilder:rbac:groups=migration.openshift.io,resources=directvolumemigrationprogresses/status,verbs=get;update;patch
-func (r *ReconcileDirectVolumeMigrationProgress) Reconcile(request reconcile.Request) (reconcile.Result, error) {
+func (r *ReconcileDirectVolumeMigrationProgress) Reconcile(ctx context.Context, request reconcile.Request) (reconcile.Result, error) {
 	var err error
-	log.Reset()
-	log.SetValues("dvmp", request.Name)
+	log = logging.WithName("pvmigrationprogress", "dvmp", request.Name)
 	// Fetch the DirectVolumeMigrationProgress instance
 	pvProgress := &migapi.DirectVolumeMigrationProgress{}
 	err = r.Get(context.TODO(), request.NamespacedName, pvProgress)
@@ -121,7 +123,7 @@ func (r *ReconcileDirectVolumeMigrationProgress) Reconcile(request reconcile.Req
 	// Set MigMigration name key on logger
 	migration, err := pvProgress.GetMigrationforDVMP(r)
 	if migration != nil {
-		log.SetValues("migMigration", migration.Name)
+		log.Real = log.WithValues("migMigration", migration.Name)
 	}
 
 	// Set up jaeger tracing
@@ -197,10 +199,8 @@ func (r *RsyncPodProgressTask) Run() error {
 		if err != nil {
 			return liberr.Wrap(err)
 		}
-		rsyncPodStatus, err := r.getRsyncClientContainerStatus(pod)
-		if err != nil {
-			return liberr.Wrap(err)
-		}
+		rsyncPodStatus := r.getRsyncClientContainerStatus(pod, r)
+
 		if rsyncPodStatus != nil {
 			pvProgress.Status.RsyncPodStatus = *rsyncPodStatus
 		}
@@ -217,22 +217,17 @@ func (r *RsyncPodProgressTask) Run() error {
 			if pvProgress.Status.RsyncPodExistsInHistory(pod.Name) {
 				continue
 			}
-			rsyncPodStatus, err := r.getRsyncClientContainerStatus(pod)
-			if err != nil {
-				return liberr.Wrap(err)
-			}
+			rsyncPodStatus := r.getRsyncClientContainerStatus(pod, r)
 			if rsyncPodStatus != nil {
 				// dead pods go in history
 				if IsPodTerminal(rsyncPodStatus.PodPhase) {
+					err := r.addDVMPDoneLabel(pod)
+					if err != nil {
+						continue
+					}
 					// merge progress stats from previous run
 					MergeProgressStats(rsyncPodStatus, &pvProgress.Status.RsyncPodStatus)
 					pvProgress.Status.RsyncPodStatuses = append(pvProgress.Status.RsyncPodStatuses, *rsyncPodStatus)
-					// for terminal pods, indicate that we are done collecting information, can safely garbage collect
-					pod.Labels[migapi.DVMPDoneLabelKey] = migapi.True
-					err := r.SrcClient.Update(context.TODO(), pod)
-					if err != nil {
-						return err
-					}
 				}
 				// update mostRecentPodStatus if current pod is more recent
 				if mostRecentPodStatus == nil ||
@@ -260,6 +255,26 @@ func (r *RsyncPodProgressTask) Run() error {
 	return nil
 }
 
+func (r *RsyncPodProgressTask) addDVMPDoneLabel(pod *kapi.Pod) error {
+	podRef := &kapi.Pod{}
+	err := r.SrcClient.Get(context.TODO(),
+		types.NamespacedName{Name: pod.Name, Namespace: pod.Namespace}, podRef)
+	if err != nil {
+		log.Info("Failed to find Pod before adding DVMP label",
+			"pod", path.Join(pod.Namespace, pod.Name))
+		return err
+	}
+	// for terminal pods, indicate that we are done collecting information, can safely garbage collect
+	podRef.Labels[migapi.DVMPDoneLabelKey] = migapi.True
+	err = r.SrcClient.Update(context.TODO(), podRef)
+	if err != nil {
+		log.Info("Failed to add DVMP label on the Pod",
+			"pod", path.Join(pod.Namespace, pod.Name))
+		return err
+	}
+	return nil
+}
+
 // MergeProgressStats merges progress stats of p2 into p1 : p1 <- p2, only if p1 & p2 are for same pods
 func MergeProgressStats(p1, p2 *migapi.RsyncPodStatus) {
 	if p1 == nil || p2 == nil || p1.PodName != p2.PodName {
@@ -323,33 +338,34 @@ func (r *RsyncPodProgressTask) updateCumulativeElapsedTime() {
 
 // getRsyncClientContainerStatus returns observed status of Rsync container in the given pod
 // podLogGetterFunction is a function capable of retrieving logs from a given pod, injected to make testing easier
-func (r *RsyncPodProgressTask) getRsyncClientContainerStatus(podRef *kapi.Pod) (*migapi.RsyncPodStatus, error) {
+func (r *RsyncPodProgressTask) getRsyncClientContainerStatus(podRef *kapi.Pod, p GetPodLogger) *migapi.RsyncPodStatus {
 	rsyncPodStatus := migapi.RsyncPodStatus{
 		PodName:           podRef.Name,
 		CreationTimestamp: &podRef.CreationTimestamp,
+		PodPhase:          podRef.Status.Phase,
+		LogMessage:        podRef.Status.Message,
 	}
 	var containerStatus *kapi.ContainerStatus
-	for _, c := range podRef.Status.ContainerStatuses {
+	for i := range podRef.Status.ContainerStatuses {
+		c := podRef.Status.ContainerStatuses[i]
 		if c.Name == RsyncContainerName {
 			containerStatus = &c
 		}
 	}
 	if containerStatus == nil {
-		if podRef.Status.Phase == kapi.PodFailed {
-			rsyncPodStatus.PodPhase = kapi.PodFailed
-			rsyncPodStatus.LogMessage = podRef.Status.Message
-			rsyncPodStatus.ContainerElapsedTime = nil
-			return &rsyncPodStatus, nil
-		}
-		return nil, fmt.Errorf("container not found")
+		log.Info("Failed to find container in Rsync Pod on source cluster",
+			"container", RsyncContainerName, "pod", path.Join(podRef.Namespace, podRef.Name))
+		return &rsyncPodStatus
 	}
 	switch {
 	case containerStatus.Ready:
 		rsyncPodStatus.PodPhase = kapi.PodRunning
 		numberOfLogLines := int64(5)
-		logMessage, err := r.getPodLogs(podRef, RsyncContainerName, &numberOfLogLines, false)
+		logMessage, err := p.getPodLogs(podRef, RsyncContainerName, &numberOfLogLines, false)
 		if err != nil {
-			return &rsyncPodStatus, err
+			log.Info("Failed to get logs from Rsync Pod on source cluster",
+				"pod", path.Join(podRef.Namespace, podRef.Name))
+			return &rsyncPodStatus
 		}
 		rsyncPodStatus.LogMessage = logMessage
 		percentProgress := GetProgressPercent(logMessage)
@@ -365,20 +381,32 @@ func (r *RsyncPodProgressTask) getRsyncClientContainerStatus(podRef *kapi.Pod) (
 		// pod has a failure, report last failure reason
 		rsyncPodStatus.PodPhase = kapi.PodFailed
 		rsyncPodStatus.LogMessage = containerStatus.LastTerminationState.Terminated.Message
+		percentProgress := GetProgressPercent(containerStatus.LastTerminationState.Terminated.Message)
+		if percentProgress != "" {
+			rsyncPodStatus.LastObservedProgressPercent = percentProgress
+		}
+		transferRate := GetTransferRate(containerStatus.LastTerminationState.Terminated.Message)
+		if transferRate != "" {
+			rsyncPodStatus.LastObservedTransferRate = transferRate
+		}
 		exitCode := containerStatus.LastTerminationState.Terminated.ExitCode
 		rsyncPodStatus.ExitCode = &exitCode
 		rsyncPodStatus.ContainerElapsedTime = &metav1.Duration{Duration: containerStatus.LastTerminationState.Terminated.FinishedAt.Sub(containerStatus.LastTerminationState.Terminated.StartedAt.Time).Round(time.Second)}
 	case !containerStatus.Ready && podRef.Status.Phase == kapi.PodPending && containerStatus.State.Waiting != nil && containerStatus.State.Waiting.Reason == ContainerCreating:
-		// if pod is not in running state after 10 mins of its creation, raise a
-		if time.Now().UTC().Sub(podRef.CreationTimestamp.Time.UTC()) > TimeLimit {
-			rsyncPodStatus.PodPhase = kapi.PodPending
-			rsyncPodStatus.LogMessage = fmt.Sprintf("Pod %s/%s is stuck in Pending state for more than 10 mins", podRef.Namespace, podRef.Name)
-			rsyncPodStatus.ContainerElapsedTime = &metav1.Duration{Duration: time.Now().Sub(podRef.CreationTimestamp.Time).Round(time.Second)}
-		}
+		rsyncPodStatus.PodPhase = kapi.PodPending
+		rsyncPodStatus.ContainerElapsedTime = &metav1.Duration{Duration: time.Now().Sub(podRef.CreationTimestamp.Time).Round(time.Second)}
 	case podRef.Status.Phase == kapi.PodFailed:
 		// Its possible for the succeeded pod to not have containerStatuses at all
 		rsyncPodStatus.PodPhase = kapi.PodFailed
 		rsyncPodStatus.LogMessage = containerStatus.State.Terminated.Message
+		percentProgress := GetProgressPercent(containerStatus.State.Terminated.Message)
+		if percentProgress != "" {
+			rsyncPodStatus.LastObservedProgressPercent = percentProgress
+		}
+		transferRate := GetTransferRate(containerStatus.State.Terminated.Message)
+		if transferRate != "" {
+			rsyncPodStatus.LastObservedTransferRate = transferRate
+		}
 		exitCode := containerStatus.State.Terminated.ExitCode
 		rsyncPodStatus.ExitCode = &exitCode
 		rsyncPodStatus.ContainerElapsedTime = &metav1.Duration{Duration: containerStatus.State.Terminated.FinishedAt.Sub(containerStatus.State.Terminated.StartedAt.Time).Round(time.Second)}
@@ -397,7 +425,7 @@ func (r *RsyncPodProgressTask) getRsyncClientContainerStatus(podRef *kapi.Pod) (
 		rsyncPodStatus.ExitCode = &exitCode
 		rsyncPodStatus.ContainerElapsedTime = &metav1.Duration{Duration: containerStatus.State.Terminated.FinishedAt.Sub(containerStatus.State.Terminated.StartedAt.Time).Round(time.Second)}
 	}
-	return &rsyncPodStatus, nil
+	return &rsyncPodStatus
 }
 
 func getPod(client compat.Client, podReference *kapi.ObjectReference) (*kapi.Pod, error) {
@@ -415,7 +443,10 @@ func getPod(client compat.Client, podReference *kapi.ObjectReference) (*kapi.Pod
 func (r *RsyncPodProgressTask) getAllMatchingRsyncPods() (*kapi.PodList, error) {
 	podList := kapi.PodList{}
 	err := r.SrcClient.List(context.TODO(),
-		client.InNamespace(r.Owner.Spec.PodNamespace).MatchingLabels(r.Owner.Spec.PodSelector), &podList)
+		&podList,
+		client.InNamespace(r.Owner.Spec.PodNamespace),
+		client.MatchingLabels(r.Owner.Spec.PodSelector),
+	)
 	if err != nil {
 		return nil, err
 	}
@@ -438,7 +469,7 @@ func (r *RsyncPodProgressTask) getPodLogs(pod *kapi.Pod, containerName string, t
 		Previous:  previous,
 		Container: containerName,
 	})
-	readCloser, err := req.Stream()
+	readCloser, err := req.Stream(context.TODO())
 	if err != nil {
 		return "", err
 	}
@@ -498,6 +529,7 @@ func parseLogs(reader io.Reader) (string, error) {
 	if err != nil {
 		return "", err
 	}
+	carriageReturnMatcher := regexp.MustCompile(`\\r.*$`)
 	data := strings.Split(buf.String(), "\n")
 	logLines := []string{}
 	for _, line := range data {
@@ -505,6 +537,12 @@ func parseLogs(reader io.Reader) (string, error) {
 		if l == "" {
 			continue
 		}
+		if carriageReturnMatcher.MatchString(l) {
+			allUpdates := strings.Split(l, "\\r")
+			if len(allUpdates) > 0 {
+				l = strings.TrimSpace(allUpdates[len(allUpdates)-1])
+			}
+		}
 		if len(l) > 60 {
 			l = l[:60]
 		}
