@@ -25,13 +25,13 @@ import (
 	"time"
 
 	"github.com/konveyor/controller/pkg/logging"
-	"github.com/konveyor/mig-controller/pkg/apis/migration/v1alpha1"
 	"github.com/konveyor/mig-controller/pkg/compat"
 	"github.com/konveyor/mig-controller/pkg/errorutil"
 	"github.com/konveyor/mig-controller/pkg/gvk"
 	"github.com/konveyor/mig-controller/pkg/settings"
 	"github.com/openshift/api/image/docker10"
 	"github.com/openshift/library-go/pkg/image/reference"
+	"github.com/opentracing/opentracing-go"
 	"k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/api/resource"
 	"k8s.io/apimachinery/pkg/runtime"
@@ -47,6 +47,7 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/source"
 
 	liberr "github.com/konveyor/controller/pkg/error"
+	"github.com/konveyor/mig-controller/pkg/apis/migration/v1alpha1"
 	migapi "github.com/konveyor/mig-controller/pkg/apis/migration/v1alpha1"
 	imagev1 "github.com/openshift/api/image/v1"
 	corev1 "k8s.io/api/core/v1"
@@ -72,7 +73,7 @@ func Add(mgr manager.Manager) error {
 
 // newReconciler returns a new reconcile.Reconciler
 func newReconciler(mgr manager.Manager) reconcile.Reconciler {
-	return &ReconcileMigAnalytic{Client: mgr.GetClient(), scheme: mgr.GetScheme(), EventRecorder: mgr.GetRecorder("miganalytic_controller")}
+	return &ReconcileMigAnalytic{Client: mgr.GetClient(), scheme: mgr.GetScheme(), EventRecorder: mgr.GetEventRecorderFor("miganalytic_controller")}
 }
 
 // add adds a new Controller to mgr with r as the reconcile.Reconciler
@@ -108,6 +109,7 @@ type ReconcileMigAnalytic struct {
 	record.EventRecorder
 
 	scheme *runtime.Scheme
+	tracer opentracing.Tracer
 }
 
 // MigAnalyticPersistentVolumeDetails defines extended properties of a volume discovered by MigAnalytic
@@ -121,10 +123,9 @@ type MigAnalyticPersistentVolumeDetails struct {
 	VolumeName          string
 }
 
-func (r *ReconcileMigAnalytic) Reconcile(request reconcile.Request) (reconcile.Result, error) {
+func (r *ReconcileMigAnalytic) Reconcile(ctx context.Context, request reconcile.Request) (reconcile.Result, error) {
 	var err error
-	log.Reset()
-	log.SetValues("migAnalytic", request.Name)
+	log = logging.WithName("analytics", "migAnalytic", request.Name)
 
 	// Fetch the MigAnalytic instance
 	analytic := &migapi.MigAnalytic{}
@@ -138,6 +139,13 @@ func (r *ReconcileMigAnalytic) Reconcile(request reconcile.Request) (reconcile.R
 		return reconcile.Result{Requeue: true}, nil
 	}
 
+	// Get jaeger span for reconcile, add to ctx
+	reconcileSpan := r.initTracer(analytic)
+	if reconcileSpan != nil {
+		ctx = opentracing.ContextWithSpan(ctx, reconcileSpan)
+		defer reconcileSpan.Finish()
+	}
+
 	// Exit early if the MigAnalytic already has a ready condition
 	// and Refresh boolean is unset
 	if analytic.Status.IsReady() && !analytic.Spec.Refresh {
@@ -263,7 +271,7 @@ func (r *ReconcileMigAnalytic) analyze(analytic *migapi.MigAnalytic) error {
 
 	analytic.Status.Analytics.Plan = plan.Name
 	analytic.Status.Analytics.Namespaces = make([]migapi.MigAnalyticNamespace, 0)
-	for i, namespace := range plan.Spec.Namespaces {
+	for i, namespace := range plan.GetSourceNamespaces() {
 		for _, ns := range analytic.Status.Analytics.Namespaces {
 			if ns.Namespace == namespace {
 				continue
@@ -300,7 +308,7 @@ func (r *ReconcileMigAnalytic) analyze(analytic *migapi.MigAnalytic) error {
 
 		if analytic.Spec.AnalyzeExtendedPVCapacity {
 			analytic.Status.SetCondition(migapi.Condition{
-				Type:     ExtendedPVAnalysisStarted,
+				Type:     migapi.ExtendedPVAnalysisStarted,
 				Category: migapi.Advisory,
 				Status:   True,
 				Message:  "Started collecting detailed PV information",
@@ -339,7 +347,7 @@ func (r *ReconcileMigAnalytic) analyze(analytic *migapi.MigAnalytic) error {
 		if err != nil {
 			return liberr.Wrap(err)
 		}
-		analytic.Status.DeleteCondition(ExtendedPVAnalysisStarted)
+		analytic.Status.DeleteCondition(migapi.ExtendedPVAnalysisStarted)
 		err = r.Update(context.TODO(), analytic)
 		if err != nil {
 			return liberr.Wrap(err)
@@ -372,13 +380,13 @@ func (r *ReconcileMigAnalytic) getNodeToPVCMapForNS(ns *migapi.MigAnalyticNamesp
 	nodeToPVDetails := map[string][]MigAnalyticPersistentVolumeDetails{}
 	err := client.List(
 		context.TODO(),
-		k8sclient.InNamespace(ns.Namespace),
-		&podList)
+		&podList,
+		k8sclient.InNamespace(ns.Namespace))
 	if err != nil {
 		return nil, liberr.Wrap(err)
 	}
 	for _, pod := range podList.Items {
-		if pod.Status.Phase == migapi.Running {
+		if pod.Status.Phase == corev1.PodRunning {
 			for _, vol := range pod.Spec.Volumes {
 				if vol.PersistentVolumeClaim != nil {
 					pvcObject := corev1.PersistentVolumeClaim{}
@@ -450,7 +458,7 @@ func (r *ReconcileMigAnalytic) analyzeK8SResources(dynamic dynamic.Interface,
 				}
 			}
 
-			list, err := dynamic.Resource(gvr).Namespace(ns.Namespace).List(metav1.ListOptions{})
+			list, err := dynamic.Resource(gvr).Namespace(ns.Namespace).List(context.Background(), metav1.ListOptions{})
 			if err != nil {
 				return liberr.Wrap(err)
 			}
@@ -501,7 +509,7 @@ func (r *ReconcileMigAnalytic) analyzeImages(client compat.Client,
 		return liberr.Wrap(err)
 	}
 
-	err = client.List(context.TODO(), k8sclient.InNamespace(namespace.Namespace), &imageStreamList)
+	err = client.List(context.TODO(), &imageStreamList, k8sclient.InNamespace(namespace.Namespace))
 	if err != nil {
 		return liberr.Wrap(err)
 	}
@@ -536,7 +544,7 @@ func (r *ReconcileMigAnalytic) analyzeImages(client compat.Client,
 func (r *ReconcileMigAnalytic) analyzePVCapacity(client compat.Client,
 	namespace *migapi.MigAnalyticNamespace) error {
 	pvcList := corev1.PersistentVolumeClaimList{}
-	err := client.List(context.TODO(), k8sclient.InNamespace(namespace.Namespace), &pvcList)
+	err := client.List(context.TODO(), &pvcList, k8sclient.InNamespace(namespace.Namespace))
 	if err != nil {
 		return liberr.Wrap(err)
 	}
@@ -633,7 +641,7 @@ func findSpecTag(tags []imagev1.TagReference, name string) *imagev1.TagReference
 func GetRegistryInfo(major, minor int, client compat.Client) (string, error) {
 	imageStreams := imagev1.ImageStreamList{}
 
-	err := client.List(context.TODO(), k8sclient.InNamespace("openshift"), &imageStreams)
+	err := client.List(context.TODO(), &imageStreams, k8sclient.InNamespace("openshift"))
 	if err == nil && len(imageStreams.Items) > 0 {
 		if value := imageStreams.Items[0].Status.DockerImageRepository; len(value) > 0 {
 			ref, err := reference.Parse(value)
