@@ -38,25 +38,25 @@ func (t *Task) ensureInitialBackup() (*velero.Backup, error) {
 	if err != nil {
 		return nil, liberr.Wrap(err)
 	}
-	newBackup, err := t.buildBackup(client)
+	newBackup, err := t.buildBackup(client, "initial")
 	if err != nil {
 		return nil, liberr.Wrap(err)
 	}
 
-	newBackup.Labels[InitialBackupLabel] = t.UID()
-	newBackup.Labels[MigMigrationDebugLabel] = t.Owner.Name
-	newBackup.Labels[MigPlanDebugLabel] = t.Owner.Spec.MigPlanRef.Name
-	newBackup.Labels[MigMigrationLabel] = string(t.Owner.UID)
-	newBackup.Labels[MigPlanLabel] = string(t.PlanResources.MigPlan.UID)
+	newBackup.Labels[migapi.InitialBackupLabel] = t.UID()
+	newBackup.Labels[migapi.MigMigrationDebugLabel] = t.Owner.Name
+	newBackup.Labels[migapi.MigPlanDebugLabel] = t.Owner.Spec.MigPlanRef.Name
+	newBackup.Labels[migapi.MigMigrationLabel] = string(t.Owner.UID)
+	newBackup.Labels[migapi.MigPlanLabel] = string(t.PlanResources.MigPlan.UID)
 	newBackup.Spec.IncludedResources = toStringSlice(settings.IncludedInitialResources.Difference(toSet(t.PlanResources.MigPlan.Status.ExcludedResources)))
 	newBackup.Spec.ExcludedResources = toStringSlice(settings.ExcludedInitialResources.Union(toSet(t.PlanResources.MigPlan.Status.ExcludedResources)))
-	delete(newBackup.Annotations, QuiesceAnnotation)
+	delete(newBackup.Annotations, migapi.QuiesceAnnotation)
 
 	if Settings.DisImgCopy {
 		if newBackup.Annotations == nil {
 			newBackup.Annotations = map[string]string{}
 		}
-		newBackup.Annotations[DisableImageCopy] = strconv.FormatBool(Settings.DisImgCopy)
+		newBackup.Annotations[migapi.DisableImageCopy] = strconv.FormatBool(Settings.DisImgCopy)
 	}
 
 	err = client.Create(context.TODO(), newBackup)
@@ -85,7 +85,7 @@ func toSet(strSlice []string) mapset.Set {
 // Get the initial backup on the source cluster.
 func (t *Task) getInitialBackup() (*velero.Backup, error) {
 	labels := t.Owner.GetCorrelationLabels()
-	labels[InitialBackupLabel] = t.UID()
+	labels[migapi.InitialBackupLabel] = t.UID()
 	return t.getBackup(labels)
 }
 
@@ -105,20 +105,20 @@ func (t *Task) ensureStageBackup() (*velero.Backup, error) {
 		return nil, liberr.Wrap(err)
 	}
 	t.Log.Info("Building Stage Velero Backup resource definition")
-	newBackup, err := t.buildBackup(client)
+	newBackup, err := t.buildBackup(client, "stage")
 	if err != nil {
 		return nil, liberr.Wrap(err)
 	}
 	labelSelector := metav1.LabelSelector{
 		MatchLabels: map[string]string{
-			IncludedInStageBackupLabel: t.UID(),
+			migapi.IncludedInStageBackupLabel: t.UID(),
 		},
 	}
-	newBackup.Labels[StageBackupLabel] = t.UID()
-	newBackup.Labels[MigMigrationDebugLabel] = t.Owner.Name
-	newBackup.Labels[MigPlanDebugLabel] = t.Owner.Spec.MigPlanRef.Name
-	newBackup.Labels[MigMigrationLabel] = string(t.Owner.UID)
-	newBackup.Labels[MigPlanLabel] = string(t.PlanResources.MigPlan.UID)
+	newBackup.Labels[migapi.StageBackupLabel] = t.UID()
+	newBackup.Labels[migapi.MigMigrationDebugLabel] = t.Owner.Name
+	newBackup.Labels[migapi.MigPlanDebugLabel] = t.Owner.Spec.MigPlanRef.Name
+	newBackup.Labels[migapi.MigMigrationLabel] = string(t.Owner.UID)
+	newBackup.Labels[migapi.MigPlanLabel] = string(t.PlanResources.MigPlan.UID)
 	var includedResources mapset.Set
 
 	if t.indirectImageMigration() || Settings.DisImgCopy {
@@ -133,7 +133,7 @@ func (t *Task) ensureStageBackup() (*velero.Backup, error) {
 		if newBackup.Annotations == nil {
 			newBackup.Annotations = map[string]string{}
 		}
-		newBackup.Annotations[DisableImageCopy] = strconv.FormatBool(Settings.DisImgCopy)
+		newBackup.Annotations[migapi.DisableImageCopy] = strconv.FormatBool(Settings.DisImgCopy)
 	}
 	t.Log.Info("Creating Stage Velero Backup on source cluster.",
 		"backup", path.Join(newBackup.Namespace, newBackup.Name))
@@ -147,7 +147,7 @@ func (t *Task) ensureStageBackup() (*velero.Backup, error) {
 // Get the stage backup on the source cluster.
 func (t *Task) getStageBackup() (*velero.Backup, error) {
 	labels := t.Owner.GetCorrelationLabels()
-	labels[StageBackupLabel] = t.UID()
+	labels[migapi.StageBackupLabel] = t.UID()
 	return t.getBackup(labels)
 }
 
@@ -163,8 +163,8 @@ func (t *Task) getPodVolumeBackupsForBackup(backup *velero.Backup) *velero.PodVo
 	}
 	err = client.List(
 		context.TODO(),
-		k8sclient.MatchingLabels(backupAssociationLabel),
-		&list)
+		&list,
+		k8sclient.MatchingLabels(backupAssociationLabel))
 	if err != nil {
 		log.Trace(err)
 	}
@@ -180,8 +180,8 @@ func (t Task) getBackup(labels map[string]string) (*velero.Backup, error) {
 	list := velero.BackupList{}
 	err = client.List(
 		context.TODO(),
-		k8sclient.MatchingLabels(labels),
-		&list)
+		&list,
+		k8sclient.MatchingLabels(labels))
 	if err != nil {
 		return nil, err
 	}
@@ -442,7 +442,7 @@ func (t *Task) getVSL() (*velero.VolumeSnapshotLocation, error) {
 }
 
 // Build a Backups as desired for the source cluster.
-func (t *Task) buildBackup(client k8sclient.Client) (*velero.Backup, error) {
+func (t *Task) buildBackup(client k8sclient.Client, backupTypePrefix string) (*velero.Backup, error) {
 	var includeClusterResources *bool = nil
 	annotations, err := t.getAnnotations(client)
 	if err != nil {
@@ -456,10 +456,17 @@ func (t *Task) buildBackup(client k8sclient.Client) (*velero.Backup, error) {
 	if err != nil {
 		return nil, liberr.Wrap(err)
 	}
+
+	// Construct a restore name like "$migrationname-54823-initial" or "$migrationname-54823-stage".
+	// This will produce a 57 character string max. Note that generateName gracefully handles strings >63 char.
+	fmtString := fmt.Sprintf("%%.%ds", 55-len(backupTypePrefix))
+	migrationNameTruncated := fmt.Sprintf(fmtString, t.Owner.GetName())
+	truncatedGenerateName := fmt.Sprintf("%s-%s-", migrationNameTruncated, backupTypePrefix)
+
 	backup := &velero.Backup{
 		ObjectMeta: metav1.ObjectMeta{
 			Labels:       t.Owner.GetCorrelationLabels(),
-			GenerateName: t.Owner.GetName() + "-",
+			GenerateName: truncatedGenerateName,
 			Namespace:    migapi.VeleroNamespace,
 			Annotations:  annotations,
 		},
@@ -487,8 +494,8 @@ func (t *Task) deleteCorrelatedBackups() error {
 	list := velero.BackupList{}
 	err = client.List(
 		context.TODO(),
-		k8sclient.MatchingLabels(t.PlanResources.MigPlan.GetCorrelationLabels()),
-		&list)
+		&list,
+		k8sclient.MatchingLabels(t.PlanResources.MigPlan.GetCorrelationLabels()))
 	if err != nil {
 		return liberr.Wrap(err)
 	}
@@ -612,8 +619,8 @@ func (t *Task) migrationUIDisRunning(migrationUID string) (bool, error) {
 	migrationList := migapi.MigMigrationList{}
 	err := t.Client.List(
 		context.TODO(),
-		k8sclient.MatchingLabels(corrLabel),
 		&migrationList,
+		k8sclient.MatchingLabels(corrLabel),
 	)
 	if err != nil {
 		return false, liberr.Wrap(err)
@@ -653,8 +660,8 @@ func (t *Task) deleteStaleBackupsOnCluster(cluster *migapi.MigCluster) (int, int
 	list := velero.BackupList{}
 	err = clusterClient.List(
 		context.TODO(),
-		k8sclient.InNamespace(migapi.VeleroNamespace),
-		&list)
+		&list,
+		k8sclient.InNamespace(migapi.VeleroNamespace))
 	if err != nil {
 		return 0, 0, liberr.Wrap(err)
 	}
@@ -744,8 +751,8 @@ func (t *Task) deleteStalePVBsOnCluster(cluster *migapi.MigCluster) (int, error)
 	list := velero.PodVolumeBackupList{}
 	err = clusterClient.List(
 		context.TODO(),
-		k8sclient.InNamespace(migapi.VeleroNamespace),
-		&list)
+		&list,
+		k8sclient.InNamespace(migapi.VeleroNamespace))
 	if err != nil {
 		return 0, liberr.Wrap(err)
 	}
