@@ -10,10 +10,8 @@ import (
 
 	liberr "github.com/konveyor/controller/pkg/error"
 	migapi "github.com/konveyor/mig-controller/pkg/apis/migration/v1alpha1"
-	"github.com/konveyor/mig-controller/pkg/gvk"
 	"github.com/pkg/errors"
 	velero "github.com/vmware-tanzu/velero/pkg/apis/velero/v1"
-	corev1 "k8s.io/api/core/v1"
 	k8serror "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
@@ -44,15 +42,15 @@ func (t *Task) ensureFinalRestore() (*velero.Restore, error) {
 	if err != nil {
 		return nil, err
 	}
-	newRestore, err := t.buildRestore(client, backup.Name)
+	newRestore, err := t.buildRestore(client, backup.Name, "final")
 	if err != nil {
 		return nil, liberr.Wrap(err)
 	}
-	newRestore.Labels[FinalRestoreLabel] = t.UID()
-	newRestore.Labels[MigMigrationDebugLabel] = t.Owner.Name
-	newRestore.Labels[MigPlanDebugLabel] = t.Owner.Spec.MigPlanRef.Name
-	newRestore.Labels[MigMigrationLabel] = string(t.Owner.UID)
-	newRestore.Labels[MigPlanLabel] = string(t.PlanResources.MigPlan.UID)
+	newRestore.Labels[migapi.FinalRestoreLabel] = t.UID()
+	newRestore.Labels[migapi.MigMigrationDebugLabel] = t.Owner.Name
+	newRestore.Labels[migapi.MigPlanDebugLabel] = t.Owner.Spec.MigPlanRef.Name
+	newRestore.Labels[migapi.MigMigrationLabel] = string(t.Owner.UID)
+	newRestore.Labels[migapi.MigPlanLabel] = string(t.PlanResources.MigPlan.UID)
 
 	t.Log.Info("Creating Velero Final Restore on target cluster.",
 		"restore", path.Join(newRestore.Namespace, newRestore.Name))
@@ -66,7 +64,7 @@ func (t *Task) ensureFinalRestore() (*velero.Restore, error) {
 // Get the final restore on the destination cluster.
 func (t *Task) getFinalRestore() (*velero.Restore, error) {
 	labels := t.Owner.GetCorrelationLabels()
-	labels[FinalRestoreLabel] = t.UID()
+	labels[migapi.FinalRestoreLabel] = t.UID()
 	return t.getRestore(labels)
 }
 
@@ -93,20 +91,20 @@ func (t *Task) ensureStageRestore() (*velero.Restore, error) {
 	if err != nil {
 		return nil, err
 	}
-	newRestore, err := t.buildRestore(client, backup.Name)
+	newRestore, err := t.buildRestore(client, backup.Name, "stage")
 	if err != nil {
 		return nil, liberr.Wrap(err)
 	}
-	newRestore.Labels[StageRestoreLabel] = t.UID()
-	newRestore.Labels[MigMigrationDebugLabel] = t.Owner.Name
-	newRestore.Labels[MigPlanDebugLabel] = t.Owner.Spec.MigPlanRef.Name
-	newRestore.Labels[MigMigrationLabel] = string(t.Owner.UID)
-	newRestore.Labels[MigPlanLabel] = string(t.PlanResources.MigPlan.UID)
+	newRestore.Labels[migapi.StageRestoreLabel] = t.UID()
+	newRestore.Labels[migapi.MigMigrationDebugLabel] = t.Owner.Name
+	newRestore.Labels[migapi.MigPlanDebugLabel] = t.Owner.Spec.MigPlanRef.Name
+	newRestore.Labels[migapi.MigMigrationLabel] = string(t.Owner.UID)
+	newRestore.Labels[migapi.MigPlanLabel] = string(t.PlanResources.MigPlan.UID)
 	stagePodImage, err := t.getStagePodImage(client)
 	if err != nil {
 		return nil, liberr.Wrap(err)
 	}
-	newRestore.Annotations[StagePodImageAnnotation] = stagePodImage
+	newRestore.Annotations[migapi.StagePodImageAnnotation] = stagePodImage
 	err = client.Create(context.TODO(), newRestore)
 	if err != nil {
 		return nil, liberr.Wrap(err)
@@ -117,7 +115,7 @@ func (t *Task) ensureStageRestore() (*velero.Restore, error) {
 // Get the stage restore on the destination cluster.
 func (t *Task) getStageRestore() (*velero.Restore, error) {
 	labels := t.Owner.GetCorrelationLabels()
-	labels[StageRestoreLabel] = t.UID()
+	labels[migapi.StageRestoreLabel] = t.UID()
 	return t.getRestore(labels)
 }
 
@@ -130,8 +128,8 @@ func (t Task) getRestore(labels map[string]string) (*velero.Restore, error) {
 	list := velero.RestoreList{}
 	err = client.List(
 		context.TODO(),
-		k8sclient.MatchingLabels(labels),
-		&list)
+		&list,
+		k8sclient.MatchingLabels(labels))
 	if err != nil {
 		return nil, err
 	}
@@ -155,8 +153,8 @@ func (t *Task) getPodVolumeRestoresForRestore(restore *velero.Restore) *velero.P
 	}
 	err = client.List(
 		context.TODO(),
-		k8sclient.MatchingLabels(restoreAssociationLabel),
-		&list)
+		&list,
+		k8sclient.MatchingLabels(restoreAssociationLabel))
 	if err != nil {
 		log.Trace(err)
 	}
@@ -376,15 +374,22 @@ func (t *Task) setFinalRestorePartialFailureWarning(restore *velero.Restore) {
 }
 
 // Build a Restore as desired for the destination cluster.
-func (t *Task) buildRestore(client k8sclient.Client, backupName string) (*velero.Restore, error) {
+func (t *Task) buildRestore(client k8sclient.Client, backupName string, restoreTypePrefix string) (*velero.Restore, error) {
 	annotations, err := t.getAnnotations(client)
 	if err != nil {
 		return nil, liberr.Wrap(err)
 	}
+
+	// Construct a name like "$migrationname-54823-stage" or "$migrationname-54823-final".
+	// This will produce a 57 character string max. Note that generateName gracefully handles strings >63 char.
+	fmtString := fmt.Sprintf("%%.%ds", 55-len(restoreTypePrefix))
+	migrationNameTruncated := fmt.Sprintf(fmtString, t.Owner.GetName())
+	truncatedGenerateName := fmt.Sprintf("%s-%s-", migrationNameTruncated, restoreTypePrefix)
+
 	restore := &velero.Restore{
 		ObjectMeta: metav1.ObjectMeta{
 			Labels:       t.Owner.GetCorrelationLabels(),
-			GenerateName: t.Owner.GetName() + "-",
+			GenerateName: truncatedGenerateName,
 			Namespace:    migapi.VeleroNamespace,
 			Annotations:  annotations,
 		},
@@ -434,8 +439,8 @@ func (t *Task) deleteCorrelatedRestores() error {
 	list := velero.RestoreList{}
 	err = client.List(
 		context.TODO(),
-		k8sclient.MatchingLabels(t.PlanResources.MigPlan.GetCorrelationLabels()),
-		&list)
+		&list,
+		k8sclient.MatchingLabels(t.PlanResources.MigPlan.GetCorrelationLabels()))
 	if err != nil {
 		return liberr.Wrap(err)
 	}
@@ -468,8 +473,8 @@ func (t *Task) deleteStaleRestoresOnCluster(cluster *migapi.MigCluster) (int, in
 	list := velero.RestoreList{}
 	err = clusterClient.List(
 		context.TODO(),
-		k8sclient.InNamespace(migapi.VeleroNamespace),
-		&list)
+		&list,
+		k8sclient.InNamespace(migapi.VeleroNamespace))
 	if err != nil {
 		return 0, 0, liberr.Wrap(err)
 	}
@@ -539,8 +544,8 @@ func (t *Task) deleteStalePVRsOnCluster(cluster *migapi.MigCluster) (int, error)
 	list := velero.PodVolumeRestoreList{}
 	err = clusterClient.List(
 		context.TODO(),
-		k8sclient.InNamespace(migapi.VeleroNamespace),
-		&list)
+		&list,
+		k8sclient.InNamespace(migapi.VeleroNamespace))
 	if err != nil {
 		return 0, liberr.Wrap(err)
 	}
@@ -619,151 +624,3 @@ func (t *Task) deleteStalePVRsOnCluster(cluster *migapi.MigCluster) (int, error)
 
 	return nDeleted, nil
 }
-
-// Delete namespace and cluster-scoped resources on dest cluster
-func (t *Task) deleteMigrated() error {
-	// TODO: delete 'deployer' Pods associated with DCs even if phase=completed
-
-	err := t.deleteMigratedNamespaceScopedResources()
-	if err != nil {
-		return liberr.Wrap(err)
-	}
-
-	err = t.deleteMovedNfsPVs()
-	if err != nil {
-		return liberr.Wrap(err)
-	}
-
-	return nil
-}
-
-// Delete migrated namespace-scoped resources on dest cluster
-func (t *Task) deleteMigratedNamespaceScopedResources() error {
-	t.Log.Info("Rollback: Scanning all GVKs in all migrated namespaces for " +
-		"MigPlan associated resources to delete.")
-	client, GVRs, err := gvk.GetNamespacedGVRsForCluster(t.PlanResources.DestMigCluster, t.Client)
-	if err != nil {
-		return liberr.Wrap(err)
-	}
-
-	listOptions := k8sclient.MatchingLabels(map[string]string{
-		MigPlanLabel: string(t.PlanResources.MigPlan.UID),
-	}).AsListOptions()
-
-	for _, gvr := range GVRs {
-		for _, ns := range t.destinationNamespaces() {
-			gvkCombined := gvr.Group + "/" + gvr.Version + "/" + gvr.Resource
-			t.Log.Info(fmt.Sprintf("Rollback: Searching destination cluster namespace for resources "+
-				"with migrated-by label."),
-				"namespace", ns,
-				"gvk", gvkCombined,
-				"label", fmt.Sprintf("%v:%v", MigPlanLabel, string(t.PlanResources.MigPlan.UID)))
-			err = client.Resource(gvr).DeleteCollection(&metav1.DeleteOptions{}, *listOptions)
-			if err == nil {
-				continue
-			}
-			if !k8serror.IsMethodNotSupported(err) && !k8serror.IsNotFound(err) {
-				return liberr.Wrap(err)
-			}
-			list, err := client.Resource(gvr).Namespace(ns).List(*listOptions)
-			if err != nil {
-				return liberr.Wrap(err)
-			}
-			for _, r := range list.Items {
-				err = client.Resource(gvr).Namespace(ns).Delete(r.GetName(), nil)
-				if err != nil {
-					// Will ignore the ones that were removed, or for some reason are not supported
-					// Assuming that main resources will be removed, such as pods and pvcs
-					if k8serror.IsMethodNotSupported(err) || k8serror.IsNotFound(err) {
-						continue
-					}
-					log.Error(err, fmt.Sprintf("Failed to request delete on: %s", gvr.String()))
-					return err
-				}
-				log.Info("DELETION REQUESTED for resource on destination cluster with matching migrated-by label",
-					"gvk", gvkCombined,
-					"resource", path.Join(ns, r.GetName()))
-			}
-		}
-	}
-
-	return nil
-}
-
-// Delete migrated NFS PV resources that were "moved" to the dest cluster
-func (t *Task) deleteMovedNfsPVs() error {
-	t.Log.Info("Starting deletion of any 'moved' NFS PVs from destination cluster")
-	dstClient, err := t.getDestinationClient()
-	if err != nil {
-		return liberr.Wrap(err)
-	}
-
-	// Only delete PVs with matching 'migrated-by-migplan' label.
-	listOptions := k8sclient.MatchingLabels(map[string]string{
-		MigPlanLabel: string(t.PlanResources.MigPlan.UID),
-	})
-	list := corev1.PersistentVolumeList{}
-	err = dstClient.List(context.TODO(), listOptions, &list)
-	if err != nil {
-		return err
-	}
-	for _, pv := range list.Items {
-		// Skip unless PV type = NFS
-		if pv.Spec.NFS == nil {
-			continue
-		}
-		// Skip delete unless ReclaimPolicy=Retain
-		if pv.Spec.PersistentVolumeReclaimPolicy != corev1.PersistentVolumeReclaimRetain {
-			continue
-		}
-		t.Log.Info("Deleting 'moved' NFS PV from destination cluster",
-			"persistentVolume", pv.Name)
-		err := dstClient.Delete(context.TODO(), &pv)
-		if err != nil {
-			if k8serror.IsMethodNotSupported(err) || k8serror.IsNotFound(err) {
-				continue
-			}
-			log.Error(err, "Failed to request delete on moved PV",
-				"persistentVolume", pv.Name)
-			return err
-		}
-		log.Info("Deleted moved NFS PV from destination cluster", "persistentVolume", pv.Name)
-	}
-
-	return nil
-}
-
-func (t *Task) ensureMigratedResourcesDeleted() (bool, error) {
-	t.Log.Info("Scanning all GVKs in all migrated namespaces to ensure " +
-		"resources have finished deleting.")
-	client, GVRs, err := gvk.GetNamespacedGVRsForCluster(t.PlanResources.DestMigCluster, t.Client)
-	if err != nil {
-		return false, liberr.Wrap(err)
-	}
-
-	listOptions := k8sclient.MatchingLabels(map[string]string{
-		MigPlanLabel: string(t.PlanResources.MigPlan.UID),
-	}).AsListOptions()
-	for _, gvr := range GVRs {
-		for _, ns := range t.destinationNamespaces() {
-			gvkCombinedName := gvr.Group + "/" + gvr.Version + "/" + gvr.Resource
-			log.Info("Rollback: Checking for leftover resources in destination cluster",
-				"gvk", gvkCombinedName, "namespace", ns)
-			list, err := client.Resource(gvr).Namespace(ns).List(*listOptions)
-			if err != nil {
-				return false, liberr.Wrap(err)
-			}
-			// Wait for resources with deletion timestamps
-			if len(list.Items) > 0 {
-				t.Log.Info("Resource(s) found with in destination cluster "+
-					"that have NOT finished terminating. These resource(s) "+
-					"are associated with the MigPlan and deletion has been requested.",
-					"gvk", gvkCombinedName,
-					"namespace", ns)
-				return false, err
-			}
-		}
-	}
-
-	return true, nil
-}
