@@ -25,12 +25,11 @@ import (
 	"time"
 
 	"github.com/konveyor/mig-controller/pkg/errorutil"
+	"github.com/opentracing/opentracing-go"
 
 	liberr "github.com/konveyor/controller/pkg/error"
 	"github.com/konveyor/controller/pkg/logging"
 	migapi "github.com/konveyor/mig-controller/pkg/apis/migration/v1alpha1"
-	miganalytic "github.com/konveyor/mig-controller/pkg/controller/miganalytic"
-	migctl "github.com/konveyor/mig-controller/pkg/controller/migmigration"
 	migref "github.com/konveyor/mig-controller/pkg/reference"
 	"github.com/konveyor/mig-controller/pkg/settings"
 	kapi "k8s.io/api/core/v1"
@@ -68,7 +67,7 @@ func Add(mgr manager.Manager) error {
 
 // newReconciler returns a new reconcile.Reconciler
 func newReconciler(mgr manager.Manager) reconcile.Reconciler {
-	return &ReconcileMigPlan{Client: mgr.GetClient(), scheme: mgr.GetScheme(), EventRecorder: mgr.GetRecorder("migplan_controller")}
+	return &ReconcileMigPlan{Client: mgr.GetClient(), scheme: mgr.GetScheme(), EventRecorder: mgr.GetEventRecorderFor("migplan_controller")}
 }
 
 // add adds a new Controller to mgr with r as the reconcile.Reconciler
@@ -92,12 +91,9 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 	// Watch for changes to MigClusters referenced by MigPlans
 	err = c.Watch(
 		&source.Kind{Type: &migapi.MigCluster{}},
-		&handler.EnqueueRequestsFromMapFunc{
-			ToRequests: handler.ToRequestsFunc(
-				func(a handler.MapObject) []reconcile.Request {
-					return migref.GetRequests(a, migapi.MigPlan{})
-				}),
-		},
+		handler.EnqueueRequestsFromMapFunc(func(a client.Object) []reconcile.Request {
+			return migref.GetRequests(a, migapi.MigPlan{})
+		}),
 		&ClusterPredicate{})
 	if err != nil {
 		return err
@@ -106,12 +102,9 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 	// Watch for changes to MigStorage referenced by MigPlans
 	err = c.Watch(
 		&source.Kind{Type: &migapi.MigStorage{}},
-		&handler.EnqueueRequestsFromMapFunc{
-			ToRequests: handler.ToRequestsFunc(
-				func(a handler.MapObject) []reconcile.Request {
-					return migref.GetRequests(a, migapi.MigPlan{})
-				}),
-		},
+		handler.EnqueueRequestsFromMapFunc(func(a client.Object) []reconcile.Request {
+			return migref.GetRequests(a, migapi.MigPlan{})
+		}),
 		&StoragePredicate{})
 	if err != nil {
 		return err
@@ -120,9 +113,7 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 	// Watch for changes to MigMigrations.
 	err = c.Watch(
 		&source.Kind{Type: &migapi.MigMigration{}},
-		&handler.EnqueueRequestsFromMapFunc{
-			ToRequests: handler.ToRequestsFunc(MigrationRequests),
-		},
+		handler.EnqueueRequestsFromMapFunc(MigrationRequests),
 		&MigrationPredicate{})
 	if err != nil {
 		return err
@@ -133,9 +124,10 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 
 	// Plan
 	err = indexer.IndexField(
+		context.Background(),
 		&migapi.MigPlan{},
 		migapi.ClosedIndexField,
-		func(rawObj runtime.Object) []string {
+		func(rawObj k8sclient.Object) []string {
 			p, cast := rawObj.(*migapi.MigPlan)
 			if !cast {
 				return nil
@@ -149,9 +141,10 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 	}
 	// Pod
 	err = indexer.IndexField(
+		context.Background(),
 		&kapi.Pod{},
 		"status.phase",
-		func(rawObj runtime.Object) []string {
+		func(rawObj k8sclient.Object) []string {
 			p, cast := rawObj.(*kapi.Pod)
 			if !cast {
 				return nil
@@ -175,12 +168,12 @@ type ReconcileMigPlan struct {
 	record.EventRecorder
 
 	scheme *runtime.Scheme
+	tracer opentracing.Tracer
 }
 
-func (r *ReconcileMigPlan) Reconcile(request reconcile.Request) (reconcile.Result, error) {
+func (r *ReconcileMigPlan) Reconcile(ctx context.Context, request reconcile.Request) (reconcile.Result, error) {
 	var err error
-	log.Reset()
-	log.SetValues("migPlan", request.Name)
+	log = logging.WithName("plan", "migPlan", request.Name)
 
 	// Fetch the MigPlan instance
 	plan := &migapi.MigPlan{}
@@ -193,6 +186,13 @@ func (r *ReconcileMigPlan) Reconcile(request reconcile.Request) (reconcile.Resul
 		return reconcile.Result{Requeue: true}, err
 	}
 
+	// Get jaeger span for reconcile, add to ctx
+	reconcileSpan := r.initTracer(plan)
+	if reconcileSpan != nil {
+		ctx = opentracing.ContextWithSpan(ctx, reconcileSpan)
+		defer reconcileSpan.Finish()
+	}
+
 	// Report reconcile error.
 	defer func() {
 		// This should only be turned on in debug mode IMO,
@@ -211,7 +211,7 @@ func (r *ReconcileMigPlan) Reconcile(request reconcile.Request) (reconcile.Resul
 	}()
 
 	// Plan closed.
-	closed, err := r.handleClosed(plan)
+	closed, err := r.handleClosed(ctx, plan)
 	if err != nil {
 		log.Trace(err)
 		return reconcile.Result{Requeue: true}, nil
@@ -224,7 +224,7 @@ func (r *ReconcileMigPlan) Reconcile(request reconcile.Request) (reconcile.Resul
 	plan.Status.BeginStagingConditions()
 
 	// Plan Suspended
-	err = r.planSuspended(plan)
+	err = r.planSuspended(ctx, plan)
 	if err != nil {
 		log.Trace(err)
 		return reconcile.Result{Requeue: true}, nil
@@ -232,7 +232,7 @@ func (r *ReconcileMigPlan) Reconcile(request reconcile.Request) (reconcile.Resul
 
 	// If intelligent pv resizing is enabled, Check if migAnalytics exists
 	if Settings.EnableIntelligentPVResize {
-		err = r.ensureMigAnalytics(plan)
+		err = r.ensureMigAnalytics(ctx, plan)
 		if err != nil {
 			log.Trace(err)
 			return reconcile.Result{Requeue: true}, nil
@@ -247,14 +247,14 @@ func (r *ReconcileMigPlan) Reconcile(request reconcile.Request) (reconcile.Resul
 	}
 
 	// Validations.
-	err = r.validate(plan)
+	err = r.validate(ctx, plan)
 	if err != nil {
 		log.Trace(err)
 		return reconcile.Result{Requeue: true}, nil
 	}
 
 	// PV discovery
-	err = r.updatePvs(plan)
+	err = r.updatePvs(ctx, plan)
 	if err != nil {
 		log.Trace(err)
 		return reconcile.Result{Requeue: true}, nil
@@ -269,14 +269,14 @@ func (r *ReconcileMigPlan) Reconcile(request reconcile.Request) (reconcile.Resul
 	}
 
 	// Validate PV actions.
-	err = r.validatePvSelections(plan)
+	err = r.validatePvSelections(ctx, plan)
 	if err != nil {
 		log.Trace(err)
 		return reconcile.Result{Requeue: true}, nil
 	}
 
 	// Storage
-	err = r.ensureStorage(plan)
+	err = r.ensureStorage(ctx, plan)
 	if err != nil {
 		log.Trace(err)
 		return reconcile.Result{Requeue: true}, nil
@@ -284,14 +284,14 @@ func (r *ReconcileMigPlan) Reconcile(request reconcile.Request) (reconcile.Resul
 
 	// If intelligent pv resizing is enabled, Wait for the migAnalytics to be ready
 	if Settings.EnableIntelligentPVResize {
-		migAnalytic, err := r.checkIfMigAnalyticsReady(plan)
+		migAnalytic, err := r.checkIfMigAnalyticsReady(ctx, plan)
 		if err != nil {
 			log.Trace(err)
 			return reconcile.Result{Requeue: true}, nil
 		}
 		if migAnalytic != nil {
 			// Process PV Capacity and generate conditions
-			r.processProposedPVCapacities(plan, migAnalytic)
+			r.processProposedPVCapacities(ctx, plan, migAnalytic)
 		}
 		if migAnalytic == nil && !plan.Status.HasCondition(PvUsageAnalysisFailed) {
 			return reconcile.Result{Requeue: true}, nil
@@ -329,7 +329,12 @@ func (r *ReconcileMigPlan) Reconcile(request reconcile.Request) (reconcile.Resul
 
 // Detect that a plan is been closed and ensure all its referenced
 // resources have been cleaned up.
-func (r *ReconcileMigPlan) handleClosed(plan *migapi.MigPlan) (bool, error) {
+func (r *ReconcileMigPlan) handleClosed(ctx context.Context, plan *migapi.MigPlan) (bool, error) {
+	if opentracing.SpanFromContext(ctx) != nil {
+		span, _ := opentracing.StartSpanFromContextWithTracer(ctx, r.tracer, "handleClosed")
+		defer span.Finish()
+	}
+
 	closed := plan.Spec.Closed
 	if !closed || plan.Status.HasCondition(Closed) {
 		return closed, nil
@@ -382,7 +387,11 @@ func (r *ReconcileMigPlan) ensureClosed(plan *migapi.MigPlan) error {
 // A plan is considered`suspended` when a migration is running or the final migration has
 // completed successfully. While suspended, reconcile is limited to basic validation
 // and PV discovery and ensuring resources is not performed.
-func (r *ReconcileMigPlan) planSuspended(plan *migapi.MigPlan) error {
+func (r *ReconcileMigPlan) planSuspended(ctx context.Context, plan *migapi.MigPlan) error {
+	if opentracing.SpanFromContext(ctx) != nil {
+		span, _ := opentracing.StartSpanFromContextWithTracer(ctx, r.tracer, "planSuspended")
+		defer span.Finish()
+	}
 	suspended := false
 
 	migrations, err := plan.ListMigrations(r)
@@ -399,17 +408,17 @@ func (r *ReconcileMigPlan) planSuspended(plan *migapi.MigPlan) error {
 
 	for _, m := range migrations {
 		// If a migration is running, plan should be suspended
-		if m.Status.HasCondition(migctl.Running) {
+		if m.Status.HasCondition(migapi.Running) {
 			suspended = true
 			break
 		}
 		// If the newest final migration is successful, suspend plan
-		if m.Status.HasCondition(migctl.Succeeded) && !m.Spec.Stage && !m.Spec.Rollback {
+		if m.Status.HasCondition(migapi.Succeeded) && !m.Spec.Stage && !m.Spec.Rollback {
 			suspended = true
 			break
 		}
 		// If the newest migration is a successful rollback, unsuspend plan
-		if m.Status.HasCondition(migctl.Succeeded) && m.Spec.Rollback {
+		if m.Status.HasCondition(migapi.Succeeded) && m.Spec.Rollback {
 			suspended = false
 			break
 		}
@@ -485,9 +494,13 @@ func (r ReconcileMigPlan) deleteImageRegistryDeploymentForClient(client k8sclien
 	return nil
 }
 
-func (r *ReconcileMigPlan) ensureMigAnalytics(plan *migapi.MigPlan) error {
+func (r *ReconcileMigPlan) ensureMigAnalytics(ctx context.Context, plan *migapi.MigPlan) error {
+	if opentracing.SpanFromContext(ctx) != nil {
+		span, _ := opentracing.StartSpanFromContextWithTracer(ctx, r.tracer, "ensureMigAnalytics")
+		defer span.Finish()
+	}
 	migAnalytics := &migapi.MigAnalyticList{}
-	err := r.List(context.TODO(), k8sclient.MatchingLabels(map[string]string{MigPlan: plan.Name}), migAnalytics)
+	err := r.List(context.TODO(), migAnalytics, k8sclient.MatchingLabels(map[string]string{MigPlan: plan.Name}))
 	if err != nil {
 		if !errors.IsNotFound(err) {
 			return liberr.Wrap(err)
@@ -525,9 +538,13 @@ func (r *ReconcileMigPlan) ensureMigAnalytics(plan *migapi.MigPlan) error {
 	return nil
 }
 
-func (r *ReconcileMigPlan) checkIfMigAnalyticsReady(plan *migapi.MigPlan) (*migapi.MigAnalytic, error) {
+func (r *ReconcileMigPlan) checkIfMigAnalyticsReady(ctx context.Context, plan *migapi.MigPlan) (*migapi.MigAnalytic, error) {
+	if opentracing.SpanFromContext(ctx) != nil {
+		span, _ := opentracing.StartSpanFromContextWithTracer(ctx, r.tracer, "checkIfMigAnalyticsReady")
+		defer span.Finish()
+	}
 	migAnalytics := &migapi.MigAnalyticList{}
-	err := r.List(context.TODO(), k8sclient.MatchingLabels(map[string]string{MigPlan: plan.Name}), migAnalytics)
+	err := r.List(context.TODO(), migAnalytics, k8sclient.MatchingLabels(map[string]string{MigPlan: plan.Name}))
 	if err != nil {
 		return nil, liberr.Wrap(err)
 	}
@@ -537,7 +554,7 @@ func (r *ReconcileMigPlan) checkIfMigAnalyticsReady(plan *migapi.MigPlan) (*miga
 			if migAnalytic.Status.IsReady() && !migAnalytic.Spec.Refresh {
 				return migAnalytic, nil
 			}
-			pvAnalysisStartedCondition := migAnalytic.Status.FindCondition(miganalytic.ExtendedPVAnalysisStarted)
+			pvAnalysisStartedCondition := migAnalytic.Status.FindCondition(migapi.ExtendedPVAnalysisStarted)
 			if pvAnalysisStartedCondition != nil {
 				if time.Now().Sub(pvAnalysisStartedCondition.LastTransitionTime.Time) > migAnalyticsTimeout {
 					plan.Status.SetCondition(migapi.Condition{
@@ -556,11 +573,19 @@ func (r *ReconcileMigPlan) checkIfMigAnalyticsReady(plan *migapi.MigPlan) (*miga
 }
 
 // processProposedPVCapacities reads miganalytic status to find proposed capacities of volumes
-func (r *ReconcileMigPlan) processProposedPVCapacities(plan *migapi.MigPlan, analytic *migapi.MigAnalytic) {
+func (r *ReconcileMigPlan) processProposedPVCapacities(ctx context.Context, plan *migapi.MigPlan, analytic *migapi.MigAnalytic) {
+	if opentracing.SpanFromContext(ctx) != nil {
+		span, _ := opentracing.StartSpanFromContextWithTracer(ctx, r.tracer, "processProposedPVCapacities")
+		defer span.Finish()
+	}
+	// list of volume names for which MigAnalytic proposed a new volume size
 	pvResizingRequiredVolumes := []string{}
+	// list of volume names for which MigAnalytic information was not found
+	pvResizingInformationMissingVolumes := []string{}
 	plan.Spec.PersistentVolumes.BeginPvStaging()
 	for i := range plan.Spec.PersistentVolumes.List {
 		planVol := &plan.Spec.PersistentVolumes.List[i]
+		found := false
 		for _, analyticNS := range analytic.Status.Analytics.Namespaces {
 			if planVol.PVC.Namespace == analyticNS.Namespace {
 				for _, analyticNSVol := range analyticNS.PersistentVolumes {
@@ -569,31 +594,35 @@ func (r *ReconcileMigPlan) processProposedPVCapacities(plan *migapi.MigPlan, ana
 						if planVol.ProposedCapacity.Cmp(analyticNSVol.ProposedCapacity) > 0 {
 							planVol.CapacityConfirmed = false
 						}
-						if analyticNSVol.Comment != miganalytic.VolumeAdjustmentNoOp {
+						if analyticNSVol.Comment != migapi.VolumeAdjustmentNoOp {
 							pvResizingRequiredVolumes = append(pvResizingRequiredVolumes, planVol.Name)
 						}
 						planVol.ProposedCapacity = analyticNSVol.ProposedCapacity
+						found = true
 					}
 				}
 			}
 		}
+		if !found {
+			pvResizingInformationMissingVolumes = append(pvResizingInformationMissingVolumes, planVol.Name)
+		}
 		plan.Spec.AddPv(*planVol)
 	}
 	plan.Spec.PersistentVolumes.EndPvStaging()
-	r.generatePVResizeConditions(pvResizingRequiredVolumes, plan, analytic)
+	r.generatePVResizeConditions(pvResizingRequiredVolumes, pvResizingInformationMissingVolumes, plan, analytic)
 }
 
 // generatePVResizeConditions generates conditions for PV resizing
-func (r ReconcileMigPlan) generatePVResizeConditions(pvResizingRequiredVolumes []string, plan *migapi.MigPlan, migAnalytic *migapi.MigAnalytic) {
-	if migAnalytic.Status.HasCondition(miganalytic.ExtendedPVAnalysisFailed) {
+func (r ReconcileMigPlan) generatePVResizeConditions(pvResizingRequiredVolumes []string, pvResizingMissingVolumes []string, plan *migapi.MigPlan, migAnalytic *migapi.MigAnalytic) {
+	if cond := migAnalytic.Status.FindCondition(migapi.ExtendedPVAnalysisFailed); cond != nil {
 		plan.Status.SetCondition(migapi.Condition{
 			Category: Warn,
 			Status:   True,
-			Type:     miganalytic.ExtendedPVAnalysisFailed,
-			Reason:   miganalytic.FailedRunningDf,
+			Type:     cond.Type,
+			Reason:   cond.Reason,
 			Message: fmt.Sprintf(
-				"Failed gathering extended PV usage information for some or all PVs, please see MigAnalytic %s/%s for details",
-				migAnalytic.Namespace, migAnalytic.Name),
+				"%s, please see MigAnalytic %s/%s for details",
+				cond.Message, migAnalytic.Namespace, migAnalytic.Name),
 		})
 	}
 	// remove pv analysis related conditions as we are here processing pvs
@@ -606,7 +635,7 @@ func (r ReconcileMigPlan) generatePVResizeConditions(pvResizingRequiredVolumes [
 				Category: Warn,
 				Reason:   NotDone,
 				Message: fmt.Sprintf(
-					"Migrating data of following volumes may result in a failure either due to mismatch in their requested and actual capacities or disk usage being close to 100%% :  [%s]",
+					"Migrating data of following volumes may result in a failure either due to mismatch in their requested and actual capacities or disk usage being close to 100%%:  [%s]",
 					strings.Join(pvResizingRequiredVolumes, ",")),
 				Durable: true,
 			})
@@ -617,7 +646,7 @@ func (r ReconcileMigPlan) generatePVResizeConditions(pvResizingRequiredVolumes [
 				Category: Warn,
 				Reason:   Done,
 				Message: fmt.Sprintf(
-					"Capacity of the following volumes will be automatically adjusted to avoid disk capacity issues in the target cluster  :  [%s]",
+					"Capacity of the following volumes will be automatically adjusted to avoid disk capacity issues in the target cluster:  [%s]",
 					strings.Join(pvResizingRequiredVolumes, ",")),
 				Durable: true,
 			})
@@ -625,4 +654,18 @@ func (r ReconcileMigPlan) generatePVResizeConditions(pvResizingRequiredVolumes [
 	} else {
 		plan.Status.DeleteCondition(PvCapacityAdjustmentRequired)
 	}
+	// PV analysis did not fail, but the pv resizing information couldn't be found for some volumes
+	// this indicates that MigAnalytic skipped these volumes for some other reason
+	if len(pvResizingMissingVolumes) > 0 {
+		plan.Status.SetCondition(migapi.Condition{
+			Type:     PvUsageAnalysisFailed,
+			Status:   True,
+			Category: Warn,
+			Reason:   NotDone,
+			Message: fmt.Sprintf(
+				"Failed to compute PV resizing data for the following volumes. PV resizing will be disabled for these volumes and the migration may fail if the volumes are full or their requested and actual capacities differ in the source cluster. Please ensure that the volumes are attached to one or more running Pods for PV resizing to work correctly: [%s]",
+				strings.Join(pvResizingMissingVolumes, ","),
+			),
+		})
+	}
 }
