@@ -15,6 +15,7 @@ import (
 	"github.com/konveyor/mig-controller/pkg/pods"
 	migref "github.com/konveyor/mig-controller/pkg/reference"
 	"github.com/konveyor/mig-controller/pkg/settings"
+	"github.com/opentracing/opentracing-go"
 	kapi "k8s.io/api/core/v1"
 	k8serror "k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/fields"
@@ -46,6 +47,8 @@ const (
 	NsLimitExceeded                            = "NamespaceLimitExceeded"
 	NsLengthExceeded                           = "NamespaceLengthExceeded"
 	NsHaveNodeSelectors                        = "NamespacesHaveNodeSelectors"
+	DuplicateNsOnSourceCluster                 = "DuplicateNamespaceOnSourceCluster"
+	DuplicateNsOnDestinationCluster            = "DuplicateNamespaceOnDestinationCluster"
 	PodLimitExceeded                           = "PodLimitExceeded"
 	SourceClusterProxySecretMisconfigured      = "SourceClusterProxySecretMisconfigured"
 	DestinationClusterProxySecretMisconfigured = "DestinationClusterProxySecretMisconfigured"
@@ -101,6 +104,7 @@ const (
 	Conflict              = "Conflict"
 	NotHealthy            = "NotHealthy"
 	NodeSelectorsDetected = "NodeSelectorsDetected"
+	DuplicateNs           = "DuplicateNamespaces"
 )
 
 // Statuses
@@ -113,76 +117,81 @@ const (
 var validAccessModes = []kapi.PersistentVolumeAccessMode{kapi.ReadWriteOnce, kapi.ReadOnlyMany, kapi.ReadWriteMany}
 
 // Validate the plan resource.
-func (r ReconcileMigPlan) validate(plan *migapi.MigPlan) error {
+func (r ReconcileMigPlan) validate(ctx context.Context, plan *migapi.MigPlan) error {
+	if opentracing.SpanFromContext(ctx) != nil {
+		var span opentracing.Span
+		span, ctx = opentracing.StartSpanFromContextWithTracer(ctx, r.tracer, "validate")
+		defer span.Finish()
+	}
 	// Source cluster
-	err := r.validateSourceCluster(plan)
+	err := r.validateSourceCluster(ctx, plan)
 	if err != nil {
 		return liberr.Wrap(err)
 	}
 
 	// Destination cluster
-	err = r.validateDestinationCluster(plan)
+	err = r.validateDestinationCluster(ctx, plan)
 	if err != nil {
 		return liberr.Wrap(err)
 	}
 
 	// Storage
-	err = r.validateStorage(plan)
+	err = r.validateStorage(ctx, plan)
 	if err != nil {
 		return liberr.Wrap(err)
 	}
 
 	// Migrated namespaces.
-	err = r.validateNamespaces(plan)
+	err = r.validateNamespaces(ctx, plan)
 	if err != nil {
 		return liberr.Wrap(err)
 	}
 
 	// Validates pod properties (e.g. limit of number of active pods, presence of node-selectors)
 	// within each namespace.
-	err = r.validatePodProperties(plan)
+	err = r.validatePodProperties(ctx, plan)
 	if err != nil {
 		return liberr.Wrap(err)
 	}
 
 	// Required namespaces.
-	err = r.validateRequiredNamespaces(plan)
+	err = r.validateRequiredNamespaces(ctx, plan)
 	if err != nil {
 		return liberr.Wrap(err)
 	}
 
 	// Conflict
-	err = r.validateConflict(plan)
+	err = r.validateConflict(ctx, plan)
 	if err != nil {
 		return liberr.Wrap(err)
 	}
 
 	// Registry proxy secret
-	err = r.validateRegistryProxySecrets(plan)
+	err = r.validateRegistryProxySecrets(ctx, plan)
 	if err != nil {
 		return liberr.Wrap(err)
 	}
 
 	// Validate health of Pods
-	err = r.validatePodHealth(plan)
+	err = r.validatePodHealth(ctx, plan)
 	if err != nil {
 		return liberr.Wrap(err)
 	}
 
 	// Hooks
-	err = r.validateHooks(plan)
+	err = r.validateHooks(ctx, plan)
 	if err != nil {
 		return liberr.Wrap(err)
 	}
 
 	// GVK
-	err = r.compareGVK(plan)
+	err = r.compareGVK(ctx, plan)
 	if err != nil {
 		return liberr.Wrap(err)
 	}
 
 	// Versions
-	err = r.validateOperatorVersions(plan)
+	err = r.validateOperatorVersions(ctx, plan)
 	if err != nil {
 		return liberr.Wrap(err)
 	}
@@ -191,7 +200,11 @@ func (r ReconcileMigPlan) validate(plan *migapi.MigPlan) error {
 }
 
 // Validate the referenced storage.
-func (r ReconcileMigPlan) validateStorage(plan *migapi.MigPlan) error {
+func (r ReconcileMigPlan) validateStorage(ctx context.Context, plan *migapi.MigPlan) error {
+	if opentracing.SpanFromContext(ctx) != nil {
+		span, _ := opentracing.StartSpanFromContextWithTracer(ctx, r.tracer, "validateStorage")
+		defer span.Finish()
+	}
 	ref := plan.Spec.MigStorageRef
 
 	// NotSet
@@ -239,7 +252,12 @@ func (r ReconcileMigPlan) validateStorage(plan *migapi.MigPlan) error {
 }
 
 // Validate the referenced assetCollection.
-func (r ReconcileMigPlan) validateNamespaces(plan *migapi.MigPlan) error {
+func (r ReconcileMigPlan) validateNamespaces(ctx context.Context, plan *migapi.MigPlan) error {
+	if opentracing.SpanFromContext(ctx) != nil {
+		span, _ := opentracing.StartSpanFromContextWithTracer(ctx, r.tracer, "validateNamespaces")
+		defer span.Finish()
+	}
+
 	count := len(plan.Spec.Namespaces)
 	if count == 0 {
 		plan.Status.SetCondition(migapi.Condition{
@@ -311,7 +329,11 @@ func (r ReconcileMigPlan) validateNamespaceLengthForDVM(plan *migapi.MigPlan) []
 // 1. Validate the total number of running pods (limit) across namespaces.
 // 2. Whether any pods have node-selectors or node names associated with it. If so, a warning is raised to indicate the
 // list of namespaces associated with that pod.
-func (r ReconcileMigPlan) validatePodProperties(plan *migapi.MigPlan) error {
+func (r ReconcileMigPlan) validatePodProperties(ctx context.Context, plan *migapi.MigPlan) error {
+	if opentracing.SpanFromContext(ctx) != nil {
+		span, _ := opentracing.StartSpanFromContextWithTracer(ctx, r.tracer, "validatePodProperties")
+		defer span.Finish()
+	}
 	if plan.Status.HasAnyCondition(Suspended, NsLimitExceeded) {
 		plan.Status.StageCondition(PodLimitExceeded)
 		return nil
@@ -340,7 +362,7 @@ func (r ReconcileMigPlan) validatePodProperties(plan *migapi.MigPlan) error {
 				}),
 			Namespace: name,
 		}
-		err := client.List(context.TODO(), &options, &list)
+		err := client.List(context.TODO(), &list, &options)
 		if err != nil {
 			return liberr.Wrap(err)
 		}
@@ -402,7 +424,11 @@ func (r ReconcileMigPlan) hasCustomNodeSelectors(podList []kapi.Pod) bool {
 }
 
 // Validate the referenced source cluster.
-func (r ReconcileMigPlan) validateSourceCluster(plan *migapi.MigPlan) error {
+func (r ReconcileMigPlan) validateSourceCluster(ctx context.Context, plan *migapi.MigPlan) error {
+	if opentracing.SpanFromContext(ctx) != nil {
+		span, _ := opentracing.StartSpanFromContextWithTracer(ctx, r.tracer, "validateSourceCluster")
+		defer span.Finish()
+	}
 	ref := plan.Spec.SrcMigClusterRef
 
 	// NotSet
@@ -465,7 +491,11 @@ func (r ReconcileMigPlan) validateSourceCluster(plan *migapi.MigPlan) error {
 }
 
 // Validate the referenced source cluster.
-func (r ReconcileMigPlan) validateDestinationCluster(plan *migapi.MigPlan) error {
+func (r ReconcileMigPlan) validateDestinationCluster(ctx context.Context, plan *migapi.MigPlan) error {
+	if opentracing.SpanFromContext(ctx) != nil {
+		span, _ := opentracing.StartSpanFromContextWithTracer(ctx, r.tracer, "validateDestinationCluster")
+		defer span.Finish()
+	}
 	ref := plan.Spec.DestMigClusterRef
 
 	// NotSet
@@ -539,7 +569,12 @@ func (r ReconcileMigPlan) validateDestinationCluster(plan *migapi.MigPlan) error
 	return nil
 }
 
-func (r ReconcileMigPlan) validateOperatorVersions(plan *migapi.MigPlan) error {
+func (r ReconcileMigPlan) validateOperatorVersions(ctx context.Context, plan *migapi.MigPlan) error {
+	if opentracing.SpanFromContext(ctx) != nil {
+		span, _ := opentracing.StartSpanFromContextWithTracer(ctx, r.tracer, "validateOperatorVersions")
+		defer span.Finish()
+	}
+
 	if plan.Status.HasAnyCondition(
 		InvalidDestinationClusterRef, InvalidDestinationCluster,
 		InvalidSourceClusterRef, InvalidSourceClusterRef) {
@@ -578,7 +613,11 @@ func (r ReconcileMigPlan) validateOperatorVersions(plan *migapi.MigPlan) error {
 }
 
 // Validate required namespaces.
-func (r ReconcileMigPlan) validateRequiredNamespaces(plan *migapi.MigPlan) error {
+func (r ReconcileMigPlan) validateRequiredNamespaces(ctx context.Context, plan *migapi.MigPlan) error {
+	if opentracing.SpanFromContext(ctx) != nil {
+		span, _ := opentracing.StartSpanFromContextWithTracer(ctx, r.tracer, "validateRequiredNamespaces")
+		defer span.Finish()
+	}
 	err := r.validateSourceNamespaces(plan)
 	if err != nil {
 		return liberr.Wrap(err)
@@ -594,14 +633,24 @@ func (r ReconcileMigPlan) validateRequiredNamespaces(plan *migapi.MigPlan) error
 // Validate required namespaces on the source cluster.
 // Returns error and the total error conditions set.
 func (r ReconcileMigPlan) validateSourceNamespaces(plan *migapi.MigPlan) error {
-	namespaces := []string{migapi.VeleroNamespace}
 	if plan.Status.HasAnyCondition(Suspended, NsLimitExceeded) {
 		plan.Status.StageCondition(NsNotFoundOnSourceCluster)
 		return nil
 	}
-	for _, ns := range plan.Spec.Namespaces {
-		namespaces = append(namespaces, ns)
+	namespaces := plan.GetSourceNamespaces()
+	duplicates := listDuplicateNamespaces(namespaces)
+	if len(duplicates) > 0 {
+		plan.Status.SetCondition(migapi.Condition{
+			Type:     DuplicateNsOnSourceCluster,
+			Status:   True,
+			Reason:   DuplicateNs,
+			Category: Critical,
+			Message:  "Duplicate source cluster namespaces [] in migplan.",
+			Items:    duplicates,
+		})
+		return nil
 	}
+	namespaces = append(namespaces, migapi.VeleroNamespace)
 	cluster, err := plan.GetSourceCluster(r)
 	if err != nil {
 		return liberr.Wrap(err)
@@ -616,8 +665,6 @@ func (r ReconcileMigPlan) validateSourceNamespaces(plan *migapi.MigPlan) error {
 	ns := kapi.Namespace{}
 	notFound := make([]string, 0)
 	for _, name := range namespaces {
-		namespaceMapping := strings.Split(name, ":")
-		name = namespaceMapping[0]
 		key := types.NamespacedName{Name: name}
 		err := client.Get(context.TODO(), key, &ns)
 		if err == nil {
@@ -647,10 +694,25 @@ func (r ReconcileMigPlan) validateSourceNamespaces(plan *migapi.MigPlan) error {
 // Validate required namespaces on the destination cluster.
 // Returns error and the total error conditions set.
 func (r ReconcileMigPlan) validateDestinationNamespaces(plan *migapi.MigPlan) error {
-	namespaces := []string{migapi.VeleroNamespace}
 	if plan.Status.HasAnyCondition(Suspended) {
 		return nil
 	}
+
+	namespaces := plan.GetDestinationNamespaces()
+	duplicates := listDuplicateNamespaces(namespaces)
+	if len(duplicates) > 0 {
+		plan.Status.SetCondition(migapi.Condition{
+			Type:     DuplicateNsOnDestinationCluster,
+			Status:   True,
+			Reason:   DuplicateNs,
+			Category: Critical,
+			Message:  "Duplicate destination cluster namespaces [] in migplan.",
+			Items:    duplicates,
+		})
+		return nil
+	}
+
+	namespaces = []string{migapi.VeleroNamespace}
 	cluster, err := plan.GetDestinationCluster(r)
 	if err != nil {
 		return liberr.Wrap(err)
@@ -691,8 +753,25 @@ func (r ReconcileMigPlan) validateDestinationNamespaces(plan *migapi.MigPlan) er
 	return nil
 }
 
+func listDuplicateNamespaces(nsList []string) []string {
+	found := make(map[string]bool)
+	duplicates := []string{}
+	for _, name := range nsList {
+		if _, value := found[name]; !value {
+			found[name] = true
+		} else {
+			duplicates = append(duplicates, name)
+		}
+	}
+	return duplicates
+}
+
 // Validate the plan does not conflict with another plan.
-func (r ReconcileMigPlan) validateConflict(plan *migapi.MigPlan) error {
+func (r ReconcileMigPlan) validateConflict(ctx context.Context, plan *migapi.MigPlan) error {
+	if opentracing.SpanFromContext(ctx) != nil {
+		span, _ := opentracing.StartSpanFromContextWithTracer(ctx, r.tracer, "validateConflict")
+		defer span.Finish()
+	}
 	plans, err := migapi.ListPlans(r)
 	if err != nil {
 		return liberr.Wrap(err)
@@ -721,7 +800,11 @@ func (r ReconcileMigPlan) validateConflict(plan *migapi.MigPlan) error {
 }
 
 // Validate PV actions.
-func (r ReconcileMigPlan) validatePvSelections(plan *migapi.MigPlan) error {
+func (r ReconcileMigPlan) validatePvSelections(ctx context.Context, plan *migapi.MigPlan) error {
+	if opentracing.SpanFromContext(ctx) != nil {
+		span, _ := opentracing.StartSpanFromContextWithTracer(ctx, r.tracer, "validatePvSelections")
+		defer span.Finish()
+	}
 	invalidAction := make([]string, 0)
 	unsupported := make([]string, 0)
 
@@ -895,7 +978,11 @@ func (r ReconcileMigPlan) validatePvSelections(plan *migapi.MigPlan) error {
 }
 
 // Validate proxy secrets. Should only exist 1 or none
-func (r ReconcileMigPlan) validateRegistryProxySecrets(plan *migapi.MigPlan) error {
+func (r ReconcileMigPlan) validateRegistryProxySecrets(ctx context.Context, plan *migapi.MigPlan) error {
+	if opentracing.SpanFromContext(ctx) != nil {
+		span, _ := opentracing.StartSpanFromContextWithTracer(ctx, r.tracer, "validateRegistryProxySecrets")
+		defer span.Finish()
+	}
 	err := r.validateSourceRegistryProxySecret(plan)
 	if err != nil {
 		return err
@@ -946,11 +1033,11 @@ func (r ReconcileMigPlan) validateSourceRegistryProxySecret(plan *migapi.MigPlan
 	}
 	err = srcClient.List(
 		context.TODO(),
+		&list,
 		&k8sclient.ListOptions{
 			Namespace:     migapi.VeleroNamespace,
 			LabelSelector: selector,
 		},
-		&list,
 	)
 	if err != nil {
 		return liberr.Wrap(err)
@@ -1008,11 +1095,11 @@ func (r ReconcileMigPlan) validateDestinationRegistryProxySecret(plan *migapi.Mi
 	}
 	err = destClient.List(
 		context.TODO(),
+		&list,
 		&k8sclient.ListOptions{
 			Namespace:     migapi.VeleroNamespace,
 			LabelSelector: selector,
 		},
-		&list,
 	)
 	if err != nil {
 		return liberr.Wrap(err)
@@ -1044,7 +1131,12 @@ func (r ReconcileMigPlan) validateDestinationRegistryProxySecret(plan *migapi.Mi
 }
 
 // Validate the pods to verify if they are healthy before migration
-func (r ReconcileMigPlan) validatePodHealth(plan *migapi.MigPlan) error {
+func (r ReconcileMigPlan) validatePodHealth(ctx context.Context, plan *migapi.MigPlan) error {
+	if opentracing.SpanFromContext(ctx) != nil {
+		span, _ := opentracing.StartSpanFromContextWithTracer(ctx, r.tracer, "validatePodHealth")
+		defer span.Finish()
+	}
+
 	if plan.Status.HasAnyCondition(Suspended) {
 		plan.Status.StageCondition(SourcePodsNotHealthy)
 		return nil
@@ -1102,14 +1194,19 @@ func (r ReconcileMigPlan) validatePodHealth(plan *migapi.MigPlan) error {
 			Status:   True,
 			Reason:   NotHealthy,
 			Category: Warn,
-			Message:  "Source namespace(s) contain unhealthy pods. See: `unhealthyNamespaces` for details.",
+			Message:  "Source namespace(s) contain unhealthy pods. See: `Status.namespaces` for details.",
 		})
 	}
 
 	return nil
 }
 
-func (r ReconcileMigPlan) validateHooks(plan *migapi.MigPlan) error {
+func (r ReconcileMigPlan) validateHooks(ctx context.Context, plan *migapi.MigPlan) error {
+	if opentracing.SpanFromContext(ctx) != nil {
+		span, _ := opentracing.StartSpanFromContextWithTracer(ctx, r.tracer, "validateHooks")
+		defer span.Finish()
+	}
+
 	var preBackupCount, postBackupCount, preRestoreCount, postRestoreCount int = 0, 0, 0, 0
 
 	for _, hook := range plan.Spec.Hooks {
